@@ -50,8 +50,8 @@ fi
 if [ -n "${HOP_CONFIG_FOLDER}" ]; then
   HOP_OPTIONS="${HOP_OPTIONS} -DHOP_CONFIG_FOLDER=${HOP_CONFIG_FOLDER}"
 fi
-if [ -n "${HOP_SHARED_JDBC_FOLDER}" ]; then
-  HOP_OPTIONS="${HOP_OPTIONS} -DHOP_SHARED_JDBC_FOLDER=${HOP_SHARED_JDBC_FOLDER}"
+if [ -n "${HOP_SHARED_JDBC_FOLDERS}" ]; then
+  HOP_OPTIONS="${HOP_OPTIONS} -DHOP_SHARED_JDBC_FOLDERS=${HOP_SHARED_JDBC_FOLDERS}"
 fi
 if [ -n "${HOP_PLUGIN_BASE_FOLDERS}" ]; then
   HOP_OPTIONS="${HOP_OPTIONS} -DHOP_PLUGIN_BASE_FOLDERS=${HOP_PLUGIN_BASE_FOLDERS}"
