@@ -17,7 +17,11 @@
 
 package org.apache.hop.core.gui.plugin.callback;
 
-import java.lang.annotation.*;
+import java.lang.annotation.Documented;
+import java.lang.annotation.ElementType;
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
+import java.lang.annotation.Target;
 
 /**
  * When a @GuiPlugin has a method painted with this annotation it is possible for other code to call
