@@ -47,7 +47,7 @@ public abstract class BasePainter<Hop extends BaseHopMeta<?>, Part extends IBase
   public static final int CORNER_RADIUS_3 = 6;
   public static final int CORNER_RADIUS_2 = 4;
 
-  protected boolean drawingEditIcons;
+  protected boolean drawingBorderAroundName;
 
   protected double zoomFactor;
 
@@ -79,6 +79,7 @@ public abstract class BasePainter<Hop extends BaseHopMeta<?>, Part extends IBase
   protected float screenMagnification;
   protected Rectangle graphPort;
   protected Rectangle viewPort;
+  protected String mouseOverName;
 
   public BasePainter(
       IGc gc,
@@ -94,7 +95,8 @@ public abstract class BasePainter<Hop extends BaseHopMeta<?>, Part extends IBase
       String noteFontName,
       int noteFontHeight,
       double zoomFactor,
-      boolean drawingEditIcons) {
+      boolean drawingBorderAroundName,
+      String mouseOverName) {
     this.gc = gc;
     this.variables = variables;
     this.subject = subject;
@@ -113,7 +115,7 @@ public abstract class BasePainter<Hop extends BaseHopMeta<?>, Part extends IBase
 
     this.magnification = 1.0f;
     this.zoomFactor = zoomFactor;
-    this.drawingEditIcons = drawingEditIcons;
+    this.drawingBorderAroundName = drawingBorderAroundName;
 
     gc.setAntialias(true);
 
@@ -121,6 +123,7 @@ public abstract class BasePainter<Hop extends BaseHopMeta<?>, Part extends IBase
     this.noteFontHeight = noteFontHeight;
 
     this.screenMagnification = 1.0f;
+    this.mouseOverName = mouseOverName;
   }
 
   public static EImage getStreamIconImage(StreamIcon streamIcon, boolean enabled) {
@@ -536,17 +539,17 @@ public abstract class BasePainter<Hop extends BaseHopMeta<?>, Part extends IBase
   /**
    * Gets drawingEditIcons
    *
-   * @return value of drawingEditIcons
+   * @return value of drawingBorderAroundName
    */
-  public boolean isDrawingEditIcons() {
-    return drawingEditIcons;
+  public boolean isDrawingBorderAroundName() {
+    return drawingBorderAroundName;
   }
 
   /**
-   * @param drawingEditIcons The drawingEditIcons to set
+   * @param drawingBorderAroundName The option to set
    */
-  public void setDrawingEditIcons(boolean drawingEditIcons) {
-    this.drawingEditIcons = drawingEditIcons;
+  public void setDrawingBorderAroundName(boolean drawingBorderAroundName) {
+    this.drawingBorderAroundName = drawingBorderAroundName;
   }
 
   /**
@@ -672,4 +675,22 @@ public abstract class BasePainter<Hop extends BaseHopMeta<?>, Part extends IBase
   public void setViewPort(Rectangle viewPort) {
     this.viewPort = viewPort;
   }
+
+  /**
+   * Gets mouseOverName
+   *
+   * @return value of mouseOverName
+   */
+  public String getMouseOverName() {
+    return mouseOverName;
+  }
+
+  /**
+   * Sets mouseOverName
+   *
+   * @param mouseOverName value of mouseOverName
+   */
+  public void setMouseOverName(String mouseOverName) {
+    this.mouseOverName = mouseOverName;
+  }
 }
