@@ -21,6 +21,7 @@ import com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.annotations.HopServerServlet;
 import org.apache.hop.core.exception.HopException;
+import org.apache.hop.core.json.HopJson;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
@@ -133,7 +134,7 @@ public class GetStatusServlet extends BaseHttpServlet implements IHopServerPlugi
       } else {
         // JSON
         //
-        ObjectMapper mapper = new ObjectMapper();
+        ObjectMapper mapper = HopJson.newMapper();
         String jsonString =
             mapper.writerWithDefaultPrettyPrinter().writeValueAsString(serverStatus);
         out.println(jsonString);
@@ -142,10 +143,11 @@ public class GetStatusServlet extends BaseHttpServlet implements IHopServerPlugi
       out.println("<HTML>");
       out.println(
           "<HEAD><TITLE>"
-              + BaseMessages.getString(PKG, "GetStatusServlet.HopHopServerStatus")
+              + BaseMessages.getString(PKG, "GetStatusServlet.HopServerStatus")
               + "</TITLE>");
       out.println("<META http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\">");
-
+      out.println("<link rel=\"icon\" type=\"image/svg+xml\" href=\"/static/images/favicon.svg\">");
+      
       int tableBorder = 1;
       if (!useLightTheme) {
         if (isJettyMode()) {
@@ -745,7 +747,7 @@ public class GetStatusServlet extends BaseHttpServlet implements IHopServerPlugi
       out.println("if( element.id.startsWith( 'j-' ) && selectedWorkflowRowIndex != -1 ) {");
       out.println(
           setupAjaxCall(
-              setupJobURI(convertContextPath(StartWorkflowServlet.CONTEXT_PATH)),
+              setupWorkflowURI(convertContextPath(StartWorkflowServlet.CONTEXT_PATH)),
               BaseMessages.getString(PKG, "GetStatusServlet.StartWorkflow.Title"),
               "'"
                   + BaseMessages.getString(PKG, "GetStatusServlet.TheWorkflow.Label")
@@ -802,7 +804,7 @@ public class GetStatusServlet extends BaseHttpServlet implements IHopServerPlugi
       out.println("if( element.id.startsWith( 'j-' ) && selectedWorkflowRowIndex != -1 ) {");
       out.println(
           setupAjaxCall(
-              setupJobURI(convertContextPath(StopWorkflowServlet.CONTEXT_PATH)),
+              setupWorkflowURI(convertContextPath(StopWorkflowServlet.CONTEXT_PATH)),
               BaseMessages.getString(PKG, "GetStatusServlet.StopWorkflow.Title"),
               "'"
                   + BaseMessages.getString(PKG, "GetStatusServlet.StopWorkflow.Success.Body1")
@@ -1119,7 +1121,7 @@ public class GetStatusServlet extends BaseHttpServlet implements IHopServerPlugi
           "    if( removeElement.id.startsWith( 'j-' ) && selectedWorkflowRowIndex != -1 ) {");
       out.println(
           setupAjaxCall(
-              setupJobURI(convertContextPath(RemoveWorkflowServlet.CONTEXT_PATH)),
+              setupWorkflowURI(convertContextPath(RemoveWorkflowServlet.CONTEXT_PATH)),
               BaseMessages.getString(PKG, "GetStatusServlet.RemoveWorkflow.Title"),
               "'"
                   + BaseMessages.getString(PKG, "GetStatusServlet.TheWorkflow.Label")
@@ -1278,7 +1280,7 @@ public class GetStatusServlet extends BaseHttpServlet implements IHopServerPlugi
         + " + '&id=' + document.getElementById( 'cellTableCell_' + selectedPipelineRowIndex ).innerHTML";
   }
 
-  private String setupJobURI(String context) {
+  private String setupWorkflowURI(String context) {
     return "'"
         + context
         + "'"
