@@ -72,6 +72,7 @@ public class ActionAbortDialog extends ActionDialog implements IActionDialog {
     Shell parent = getParent();
 
     shell = new Shell(parent, SWT.DIALOG_TRIM | SWT.MIN | SWT.MAX | SWT.RESIZE);
+    shell.setMinimumSize(400, 200);
     PropsUi.setLook(shell);
     WorkflowDialog.setShellImage(shell, action);
 
@@ -91,7 +92,8 @@ public class ActionAbortDialog extends ActionDialog implements IActionDialog {
 
     // Filename line
     Label wlName = new Label(shell, SWT.RIGHT);
-    wlName.setText(BaseMessages.getString(PKG, "ActionAbortDialog.Label"));
+    wlName.setText(BaseMessages.getString(PKG, "System.ActionName.Label"));
+    wlName.setToolTipText(BaseMessages.getString(PKG, "System.ActionName.Tooltip"));
     PropsUi.setLook(wlName);
     FormData fdlName = new FormData();
     fdlName.left = new FormAttachment(0, 0);
@@ -113,7 +115,7 @@ public class ActionAbortDialog extends ActionDialog implements IActionDialog {
     PropsUi.setLook(wlMessageAbort);
     FormData fdlMessageAbort = new FormData();
     fdlMessageAbort.left = new FormAttachment(0, 0);
-    fdlMessageAbort.right = new FormAttachment(middle, 0);
+    fdlMessageAbort.right = new FormAttachment(middle, -margin);
     fdlMessageAbort.top = new FormAttachment(wName, margin);
     wlMessageAbort.setLayoutData(fdlMessageAbort);
 
@@ -150,7 +152,7 @@ public class ActionAbortDialog extends ActionDialog implements IActionDialog {
     wCancel.setText(BaseMessages.getString(PKG, "System.Button.Cancel"));
     wCancel.addListener(SWT.Selection, (Event e) -> cancel());
     BaseTransformDialog.positionBottomButtons(
-        shell, new Button[] {wOk, wCancel}, margin, 0, wAlwaysLogRows);
+        shell, new Button[] {wOk, wCancel}, margin, 0, null);
 
     getData();
 
