@@ -22,7 +22,10 @@ import org.apache.hop.core.Props;
 import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
+import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
+import org.apache.hop.ui.core.dialog.MessageBox;
+import org.apache.hop.ui.core.gui.GuiResource;
 import org.apache.hop.ui.core.widget.TextVar;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.apache.hop.ui.workflow.action.ActionDialog;
@@ -40,7 +43,12 @@ import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.layout.FormAttachment;
 import org.eclipse.swt.layout.FormData;
 import org.eclipse.swt.layout.FormLayout;
-import org.eclipse.swt.widgets.*;
+import org.eclipse.swt.widgets.Button;
+import org.eclipse.swt.widgets.Composite;
+import org.eclipse.swt.widgets.Group;
+import org.eclipse.swt.widgets.Label;
+import org.eclipse.swt.widgets.Shell;
+import org.eclipse.swt.widgets.Text;
 
 /** This dialog allows you to edit the Unzip action settings. */
 public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
@@ -128,21 +136,21 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     Shell parent = getParent();
 
     shell = new Shell(parent, SWT.DIALOG_TRIM | SWT.MIN | SWT.MAX | SWT.RESIZE);
-    props.setLook(shell);
+    PropsUi.setLook(shell);
     WorkflowDialog.setShellImage(shell, action);
 
     ModifyListener lsMod = e -> action.setChanged();
     changed = action.hasChanged();
 
     FormLayout formLayout = new FormLayout();
-    formLayout.marginWidth = Const.FORM_MARGIN;
-    formLayout.marginHeight = Const.FORM_MARGIN;
+    formLayout.marginWidth = PropsUi.getFormMargin();
+    formLayout.marginHeight = PropsUi.getFormMargin();
 
     shell.setLayout(formLayout);
     shell.setText(BaseMessages.getString(PKG, "ActionUnZip.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = Const.MARGIN;
+    int margin = PropsUi.getMargin();
 
     // Buttons go at the very bottom
     //
@@ -157,14 +165,14 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // ZipFilename line
     Label wlName = new Label(shell, SWT.RIGHT);
     wlName.setText(BaseMessages.getString(PKG, "ActionUnZip.Name.Label"));
-    props.setLook(wlName);
+    PropsUi.setLook(wlName);
     FormData fdlName = new FormData();
     fdlName.left = new FormAttachment(0, 0);
     fdlName.right = new FormAttachment(middle, -margin);
     fdlName.top = new FormAttachment(0, margin);
     wlName.setLayoutData(fdlName);
     wName = new Text(shell, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
-    props.setLook(wName);
+    PropsUi.setLook(wName);
     wName.addModifyListener(lsMod);
     FormData fdName = new FormData();
     fdName.left = new FormAttachment(middle, 0);
@@ -173,17 +181,18 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     wName.setLayoutData(fdName);
 
     CTabFolder wTabFolder = new CTabFolder(shell, SWT.BORDER);
-    props.setLook(wTabFolder, Props.WIDGET_STYLE_TAB);
+    PropsUi.setLook(wTabFolder, Props.WIDGET_STYLE_TAB);
 
     // ////////////////////////
     // START OF GENERAL TAB ///
     // ////////////////////////
 
     CTabItem wGeneralTab = new CTabItem(wTabFolder, SWT.NONE);
+    wGeneralTab.setFont(GuiResource.getInstance().getFontDefault());
     wGeneralTab.setText(BaseMessages.getString(PKG, "ActionUnZip.Tab.General.Label"));
 
     Composite wGeneralComp = new Composite(wTabFolder, SWT.NONE);
-    props.setLook(wGeneralComp);
+    PropsUi.setLook(wGeneralComp);
 
     FormLayout generalLayout = new FormLayout();
     generalLayout.marginWidth = 3;
@@ -195,7 +204,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // START OF file source GROUP///
     // /
     Group wSource = new Group(wGeneralComp, SWT.SHADOW_NONE);
-    props.setLook(wSource);
+    PropsUi.setLook(wSource);
     wSource.setText(BaseMessages.getString(PKG, "ActionUnZip.Source.Group.Label"));
 
     FormLayout groupSourceLayout = new FormLayout();
@@ -208,14 +217,14 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // Get args from previous
     Label wlArgsPrevious = new Label(wSource, SWT.RIGHT);
     wlArgsPrevious.setText(BaseMessages.getString(PKG, "ActionUnZip.ArgsPrevious.Label"));
-    props.setLook(wlArgsPrevious);
+    PropsUi.setLook(wlArgsPrevious);
     FormData fdlArgsPrevious = new FormData();
     fdlArgsPrevious.left = new FormAttachment(0, 0);
     fdlArgsPrevious.top = new FormAttachment(0, margin);
     fdlArgsPrevious.right = new FormAttachment(middle, -margin);
     wlArgsPrevious.setLayoutData(fdlArgsPrevious);
     wArgsPrevious = new Button(wSource, SWT.CHECK);
-    props.setLook(wArgsPrevious);
+    PropsUi.setLook(wArgsPrevious);
     wArgsPrevious.setToolTipText(BaseMessages.getString(PKG, "ActionUnZip.ArgsPrevious.Tooltip"));
     FormData fdArgsPrevious = new FormData();
     fdArgsPrevious.left = new FormAttachment(middle, 0);
@@ -234,7 +243,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // ZipFilename line
     wlZipFilename = new Label(wSource, SWT.RIGHT);
     wlZipFilename.setText(BaseMessages.getString(PKG, "ActionUnZip.ZipFilename.Label"));
-    props.setLook(wlZipFilename);
+    PropsUi.setLook(wlZipFilename);
     FormData fdlZipFilename = new FormData();
     fdlZipFilename.left = new FormAttachment(0, 0);
     fdlZipFilename.top = new FormAttachment(wlArgsPrevious, 2 * margin);
@@ -243,7 +252,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
 
     // Browse Source folders button ...
     wbSourceDirectory = new Button(wSource, SWT.PUSH | SWT.CENTER);
-    props.setLook(wbSourceDirectory);
+    PropsUi.setLook(wbSourceDirectory);
     wbSourceDirectory.setText(BaseMessages.getString(PKG, "ActionUnZip.BrowseFolders.Label"));
     FormData fdbSourceDirectory = new FormData();
     fdbSourceDirectory.right = new FormAttachment(100, 0);
@@ -255,7 +264,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
 
     // Browse files...
     wbZipFilename = new Button(wSource, SWT.PUSH | SWT.CENTER);
-    props.setLook(wbZipFilename);
+    PropsUi.setLook(wbZipFilename);
     wbZipFilename.setText(BaseMessages.getString(PKG, "ActionUnZip.BrowseFiles.Label"));
     FormData fdbZipFilename = new FormData();
     fdbZipFilename.right = new FormAttachment(wbSourceDirectory, -margin);
@@ -263,7 +272,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     wbZipFilename.setLayoutData(fdbZipFilename);
 
     wZipFilename = new TextVar(variables, wSource, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
-    props.setLook(wZipFilename);
+    PropsUi.setLook(wZipFilename);
     wZipFilename.addModifyListener(lsMod);
     FormData fdZipFilename = new FormData();
     fdZipFilename.left = new FormAttachment(middle, 0);
@@ -290,7 +299,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // WildcardSource line
     wlWildcardSource = new Label(wSource, SWT.RIGHT);
     wlWildcardSource.setText(BaseMessages.getString(PKG, "ActionUnZip.WildcardSource.Label"));
-    props.setLook(wlWildcardSource);
+    PropsUi.setLook(wlWildcardSource);
     FormData fdlWildcardSource = new FormData();
     fdlWildcardSource.left = new FormAttachment(0, 0);
     fdlWildcardSource.top = new FormAttachment(wZipFilename, margin);
@@ -302,7 +311,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
             wSource,
             SWT.SINGLE | SWT.LEFT | SWT.BORDER,
             BaseMessages.getString(PKG, "ActionUnZip.WildcardSource.Tooltip"));
-    props.setLook(wWildcardSource);
+    PropsUi.setLook(wWildcardSource);
     wWildcardSource.addModifyListener(lsMod);
     FormData fdWildcardSource = new FormData();
     fdWildcardSource.left = new FormAttachment(middle, 0);
@@ -323,7 +332,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // START OF UNZIPPED FILES GROUP///
     // /
     Group wUnzippedFiles = new Group(wGeneralComp, SWT.SHADOW_NONE);
-    props.setLook(wUnzippedFiles);
+    PropsUi.setLook(wUnzippedFiles);
     wUnzippedFiles.setText(BaseMessages.getString(PKG, "ActionUnZip.UnzippedFiles.Group.Label"));
 
     FormLayout groupLayoutUnzipped = new FormLayout();
@@ -336,14 +345,14 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // Use zipfile name as root directory
     Label wlRootZip = new Label(wUnzippedFiles, SWT.RIGHT);
     wlRootZip.setText(BaseMessages.getString(PKG, "ActionUnZip.RootZip.Label"));
-    props.setLook(wlRootZip);
+    PropsUi.setLook(wlRootZip);
     FormData fdlRootZip = new FormData();
     fdlRootZip.left = new FormAttachment(0, 0);
     fdlRootZip.top = new FormAttachment(wSource, margin);
     fdlRootZip.right = new FormAttachment(middle, -margin);
     wlRootZip.setLayoutData(fdlRootZip);
     wRootZip = new Button(wUnzippedFiles, SWT.CHECK);
-    props.setLook(wRootZip);
+    PropsUi.setLook(wRootZip);
     wRootZip.setToolTipText(BaseMessages.getString(PKG, "ActionUnZip.RootZip.Tooltip"));
     FormData fdRootZip = new FormData();
     fdRootZip.left = new FormAttachment(middle, 0);
@@ -361,7 +370,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // TargetDirectory line
     Label wlTargetDirectory = new Label(wUnzippedFiles, SWT.RIGHT);
     wlTargetDirectory.setText(BaseMessages.getString(PKG, "ActionUnZip.TargetDir.Label"));
-    props.setLook(wlTargetDirectory);
+    PropsUi.setLook(wlTargetDirectory);
     FormData fdlTargetDirectory = new FormData();
     fdlTargetDirectory.left = new FormAttachment(0, 0);
     fdlTargetDirectory.top = new FormAttachment(wlRootZip, 2 * margin);
@@ -370,7 +379,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
 
     // Browse folders button ...
     Button wbTargetDirectory = new Button(wUnzippedFiles, SWT.PUSH | SWT.CENTER);
-    props.setLook(wbTargetDirectory);
+    PropsUi.setLook(wbTargetDirectory);
     wbTargetDirectory.setText(BaseMessages.getString(PKG, "ActionUnZip.BrowseFolders.Label"));
     FormData fdbTargetDirectory = new FormData();
     fdbTargetDirectory.right = new FormAttachment(100, 0);
@@ -385,7 +394,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
             wUnzippedFiles,
             SWT.SINGLE | SWT.LEFT | SWT.BORDER,
             BaseMessages.getString(PKG, "ActionUnZip.TargetDir.Tooltip"));
-    props.setLook(wTargetDirectory);
+    PropsUi.setLook(wTargetDirectory);
     wTargetDirectory.addModifyListener(lsMod);
     FormData fdTargetDirectory = new FormData();
     fdTargetDirectory.left = new FormAttachment(middle, 0);
@@ -396,7 +405,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // Create Folder
     Label wlCreateFolder = new Label(wUnzippedFiles, SWT.RIGHT);
     wlCreateFolder.setText(BaseMessages.getString(PKG, "ActionUnZip.CreateFolder.Label"));
-    props.setLook(wlCreateFolder);
+    PropsUi.setLook(wlCreateFolder);
     FormData fdlCreateFolder = new FormData();
     fdlCreateFolder.left = new FormAttachment(0, 0);
     fdlCreateFolder.top = new FormAttachment(wTargetDirectory, margin);
@@ -404,7 +413,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     wlCreateFolder.setLayoutData(fdlCreateFolder);
     wCreateFolder = new Button(wUnzippedFiles, SWT.CHECK);
     wCreateFolder.setToolTipText(BaseMessages.getString(PKG, "ActionUnZip.CreateFolder.Tooltip"));
-    props.setLook(wCreateFolder);
+    PropsUi.setLook(wCreateFolder);
     FormData fdCreateFolder = new FormData();
     fdCreateFolder.left = new FormAttachment(middle, 0);
     fdCreateFolder.top = new FormAttachment(wlCreateFolder, 0, SWT.CENTER);
@@ -421,7 +430,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // Wildcard line
     Label wlWildcard = new Label(wUnzippedFiles, SWT.RIGHT);
     wlWildcard.setText(BaseMessages.getString(PKG, "ActionUnZip.Wildcard.Label"));
-    props.setLook(wlWildcard);
+    PropsUi.setLook(wlWildcard);
     FormData fdlWildcard = new FormData();
     fdlWildcard.left = new FormAttachment(0, 0);
     fdlWildcard.top = new FormAttachment(wlCreateFolder, 2 * margin);
@@ -433,7 +442,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
             wUnzippedFiles,
             SWT.SINGLE | SWT.LEFT | SWT.BORDER,
             BaseMessages.getString(PKG, "ActionUnZip.Wildcard.Tooltip"));
-    props.setLook(wWildcard);
+    PropsUi.setLook(wWildcard);
     wWildcard.addModifyListener(lsMod);
     FormData fdWildcard = new FormData();
     fdWildcard.left = new FormAttachment(middle, 0);
@@ -444,7 +453,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // Wildcard to exclude
     Label wlWildcardExclude = new Label(wUnzippedFiles, SWT.RIGHT);
     wlWildcardExclude.setText(BaseMessages.getString(PKG, "ActionUnZip.WildcardExclude.Label"));
-    props.setLook(wlWildcardExclude);
+    PropsUi.setLook(wlWildcardExclude);
     FormData fdlWildcardExclude = new FormData();
     fdlWildcardExclude.left = new FormAttachment(0, 0);
     fdlWildcardExclude.top = new FormAttachment(wWildcard, margin);
@@ -456,7 +465,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
             wUnzippedFiles,
             SWT.SINGLE | SWT.LEFT | SWT.BORDER,
             BaseMessages.getString(PKG, "ActionUnZip.WildcardExclude.Tooltip"));
-    props.setLook(wWildcardExclude);
+    PropsUi.setLook(wWildcardExclude);
     wWildcardExclude.addModifyListener(lsMod);
     FormData fdWildcardExclude = new FormData();
     fdWildcardExclude.left = new FormAttachment(middle, 0);
@@ -467,14 +476,14 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // Create multi-part file?
     wlAddDate = new Label(wUnzippedFiles, SWT.RIGHT);
     wlAddDate.setText(BaseMessages.getString(PKG, "ActionUnZip.AddDate.Label"));
-    props.setLook(wlAddDate);
+    PropsUi.setLook(wlAddDate);
     FormData fdlAddDate = new FormData();
     fdlAddDate.left = new FormAttachment(0, 0);
     fdlAddDate.top = new FormAttachment(wWildcardExclude, margin);
     fdlAddDate.right = new FormAttachment(middle, -margin);
     wlAddDate.setLayoutData(fdlAddDate);
     wAddDate = new Button(wUnzippedFiles, SWT.CHECK);
-    props.setLook(wAddDate);
+    PropsUi.setLook(wAddDate);
     wAddDate.setToolTipText(BaseMessages.getString(PKG, "ActionUnZip.AddDate.Tooltip"));
     FormData fdAddDate = new FormData();
     fdAddDate.left = new FormAttachment(middle, 0);
@@ -492,14 +501,14 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // Create multi-part file?
     wlAddTime = new Label(wUnzippedFiles, SWT.RIGHT);
     wlAddTime.setText(BaseMessages.getString(PKG, "ActionUnZip.AddTime.Label"));
-    props.setLook(wlAddTime);
+    PropsUi.setLook(wlAddTime);
     FormData fdlAddTime = new FormData();
     fdlAddTime.left = new FormAttachment(0, 0);
     fdlAddTime.top = new FormAttachment(wlAddDate, 2 * margin);
     fdlAddTime.right = new FormAttachment(middle, -margin);
     wlAddTime.setLayoutData(fdlAddTime);
     wAddTime = new Button(wUnzippedFiles, SWT.CHECK);
-    props.setLook(wAddTime);
+    PropsUi.setLook(wAddTime);
     wAddTime.setToolTipText(BaseMessages.getString(PKG, "ActionUnZip.AddTime.Tooltip"));
     FormData fdAddTime = new FormData();
     fdAddTime.left = new FormAttachment(middle, 0);
@@ -518,14 +527,14 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // Specify date time format?
     Label wlSpecifyFormat = new Label(wUnzippedFiles, SWT.RIGHT);
     wlSpecifyFormat.setText(BaseMessages.getString(PKG, "ActionUnZip.SpecifyFormat.Label"));
-    props.setLook(wlSpecifyFormat);
+    PropsUi.setLook(wlSpecifyFormat);
     FormData fdlSpecifyFormat = new FormData();
     fdlSpecifyFormat.left = new FormAttachment(0, 0);
     fdlSpecifyFormat.top = new FormAttachment(wlAddTime, 2 * margin);
     fdlSpecifyFormat.right = new FormAttachment(middle, -margin);
     wlSpecifyFormat.setLayoutData(fdlSpecifyFormat);
     wSpecifyFormat = new Button(wUnzippedFiles, SWT.CHECK);
-    props.setLook(wSpecifyFormat);
+    PropsUi.setLook(wSpecifyFormat);
     wSpecifyFormat.setToolTipText(BaseMessages.getString(PKG, "ActionUnZip.SpecifyFormat.Tooltip"));
     FormData fdSpecifyFormat = new FormData();
     fdSpecifyFormat.left = new FormAttachment(middle, 0);
@@ -547,7 +556,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // DateTimeFormat
     wlDateTimeFormat = new Label(wUnzippedFiles, SWT.RIGHT);
     wlDateTimeFormat.setText(BaseMessages.getString(PKG, "ActionUnZip.DateTimeFormat.Label"));
-    props.setLook(wlDateTimeFormat);
+    PropsUi.setLook(wlDateTimeFormat);
     FormData fdlDateTimeFormat = new FormData();
     fdlDateTimeFormat.left = new FormAttachment(0, 0);
     fdlDateTimeFormat.top = new FormAttachment(wlSpecifyFormat, 2 * margin);
@@ -555,7 +564,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     wlDateTimeFormat.setLayoutData(fdlDateTimeFormat);
     wDateTimeFormat = new CCombo(wUnzippedFiles, SWT.BORDER | SWT.READ_ONLY);
     wDateTimeFormat.setEditable(true);
-    props.setLook(wDateTimeFormat);
+    PropsUi.setLook(wDateTimeFormat);
     wDateTimeFormat.addModifyListener(lsMod);
     FormData fdDateTimeFormat = new FormData();
     fdDateTimeFormat.left = new FormAttachment(middle, 0);
@@ -569,14 +578,14 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     wlAddOriginalTimestamp = new Label(wUnzippedFiles, SWT.RIGHT);
     wlAddOriginalTimestamp.setText(
         BaseMessages.getString(PKG, "ActionUnZip.AddOriginalTimestamp.Label"));
-    props.setLook(wlAddOriginalTimestamp);
+    PropsUi.setLook(wlAddOriginalTimestamp);
     FormData fdlAddOriginalTimestamp = new FormData();
     fdlAddOriginalTimestamp.left = new FormAttachment(0, 0);
     fdlAddOriginalTimestamp.top = new FormAttachment(wDateTimeFormat, margin);
     fdlAddOriginalTimestamp.right = new FormAttachment(middle, -margin);
     wlAddOriginalTimestamp.setLayoutData(fdlAddOriginalTimestamp);
     wAddOriginalTimestamp = new Button(wUnzippedFiles, SWT.CHECK);
-    props.setLook(wAddOriginalTimestamp);
+    PropsUi.setLook(wAddOriginalTimestamp);
     wAddOriginalTimestamp.setToolTipText(
         BaseMessages.getString(PKG, "ActionUnZip.AddOriginalTimestamp.Tooltip"));
     FormData fdAddOriginalTimestamp = new FormData();
@@ -596,14 +605,14 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     Label wlSetModificationDateToOriginal = new Label(wUnzippedFiles, SWT.RIGHT);
     wlSetModificationDateToOriginal.setText(
         BaseMessages.getString(PKG, "ActionUnZip.SetModificationDateToOriginal.Label"));
-    props.setLook(wlSetModificationDateToOriginal);
+    PropsUi.setLook(wlSetModificationDateToOriginal);
     FormData fdlSetModificationDateToOriginal = new FormData();
     fdlSetModificationDateToOriginal.left = new FormAttachment(0, 0);
     fdlSetModificationDateToOriginal.top = new FormAttachment(wlAddOriginalTimestamp, 2 * margin);
     fdlSetModificationDateToOriginal.right = new FormAttachment(middle, -margin);
     wlSetModificationDateToOriginal.setLayoutData(fdlSetModificationDateToOriginal);
     wSetModificationDateToOriginal = new Button(wUnzippedFiles, SWT.CHECK);
-    props.setLook(wSetModificationDateToOriginal);
+    PropsUi.setLook(wSetModificationDateToOriginal);
     wSetModificationDateToOriginal.setToolTipText(
         BaseMessages.getString(PKG, "ActionUnZip.SetModificationDateToOriginal.Tooltip"));
     FormData fdSetModificationDateToOriginal = new FormData();
@@ -622,7 +631,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // If File Exists
     Label wlIfFileExists = new Label(wUnzippedFiles, SWT.RIGHT);
     wlIfFileExists.setText(BaseMessages.getString(PKG, "ActionUnZip.IfFileExists.Label"));
-    props.setLook(wlIfFileExists);
+    PropsUi.setLook(wlIfFileExists);
     FormData fdlIfFileExists = new FormData();
     fdlIfFileExists.left = new FormAttachment(0, 0);
     fdlIfFileExists.right = new FormAttachment(middle, -margin);
@@ -631,7 +640,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     wIfFileExists = new CCombo(wUnzippedFiles, SWT.SINGLE | SWT.READ_ONLY | SWT.BORDER);
     wIfFileExists.setItems(ActionUnZip.typeIfFileExistsDesc);
     wIfFileExists.select(0); // +1: starts at -1
-    props.setLook(wIfFileExists);
+    PropsUi.setLook(wIfFileExists);
 
     FormData fdIfFileExists = new FormData();
     fdIfFileExists.left = new FormAttachment(middle, 0);
@@ -648,7 +657,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // After Zipping
     Label wlAfterUnZip = new Label(wUnzippedFiles, SWT.RIGHT);
     wlAfterUnZip.setText(BaseMessages.getString(PKG, "ActionUnZip.AfterUnZip.Label"));
-    props.setLook(wlAfterUnZip);
+    PropsUi.setLook(wlAfterUnZip);
     FormData fdlAfterUnZip = new FormData();
     fdlAfterUnZip.left = new FormAttachment(0, 0);
     fdlAfterUnZip.right = new FormAttachment(middle, 0);
@@ -661,7 +670,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
 
     wAfterUnZip.select(0); // +1: starts at -1
 
-    props.setLook(wAfterUnZip);
+    PropsUi.setLook(wAfterUnZip);
     FormData fdAfterUnZip = new FormData();
     fdAfterUnZip.left = new FormAttachment(middle, 0);
     fdAfterUnZip.top = new FormAttachment(wIfFileExists, margin);
@@ -679,7 +688,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // moveTo Directory
     wlMovetoDirectory = new Label(wUnzippedFiles, SWT.RIGHT);
     wlMovetoDirectory.setText(BaseMessages.getString(PKG, "ActionUnZip.MovetoDirectory.Label"));
-    props.setLook(wlMovetoDirectory);
+    PropsUi.setLook(wlMovetoDirectory);
     FormData fdlMovetoDirectory = new FormData();
     fdlMovetoDirectory.left = new FormAttachment(0, 0);
     fdlMovetoDirectory.top = new FormAttachment(wAfterUnZip, margin);
@@ -691,11 +700,11 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
             wUnzippedFiles,
             SWT.SINGLE | SWT.LEFT | SWT.BORDER,
             BaseMessages.getString(PKG, "ActionUnZip.MovetoDirectory.Tooltip"));
-    props.setLook(wMovetoDirectory);
+    PropsUi.setLook(wMovetoDirectory);
 
     // Browse folders button ...
     wbMovetoDirectory = new Button(wUnzippedFiles, SWT.PUSH | SWT.CENTER);
-    props.setLook(wbMovetoDirectory);
+    PropsUi.setLook(wbMovetoDirectory);
     wbMovetoDirectory.setText(BaseMessages.getString(PKG, "ActionUnZip.BrowseFolders.Label"));
     FormData fdbMovetoDirectory = new FormData();
     fdbMovetoDirectory.right = new FormAttachment(100, 0);
@@ -715,14 +724,14 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     wlCreateMoveToDirectory = new Label(wUnzippedFiles, SWT.RIGHT);
     wlCreateMoveToDirectory.setText(
         BaseMessages.getString(PKG, "ActionUnZip.createMoveToFolder.Label"));
-    props.setLook(wlCreateMoveToDirectory);
+    PropsUi.setLook(wlCreateMoveToDirectory);
     FormData fdlcreateMoveToDirectory = new FormData();
     fdlcreateMoveToDirectory.left = new FormAttachment(0, 0);
     fdlcreateMoveToDirectory.top = new FormAttachment(wMovetoDirectory, margin);
     fdlcreateMoveToDirectory.right = new FormAttachment(middle, -margin);
     wlCreateMoveToDirectory.setLayoutData(fdlcreateMoveToDirectory);
     wCreateMoveToDirectory = new Button(wUnzippedFiles, SWT.CHECK);
-    props.setLook(wCreateMoveToDirectory);
+    PropsUi.setLook(wCreateMoveToDirectory);
     wCreateMoveToDirectory.setToolTipText(
         BaseMessages.getString(PKG, "ActionUnZip.createMoveToFolder.Tooltip"));
     FormData fdCreateMoveToDirectory = new FormData();
@@ -756,7 +765,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
 
     wGeneralComp.layout();
     wGeneralTab.setControl(wGeneralComp);
-    props.setLook(wGeneralComp);
+    PropsUi.setLook(wGeneralComp);
     // ///////////////////////////////////////////////////////////
     // / END OF GENERAL TAB
     // ///////////////////////////////////////////////////////////
@@ -766,10 +775,11 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // ////////////////////////
 
     CTabItem wAdvancedTab = new CTabItem(wTabFolder, SWT.NONE);
+    wAdvancedTab.setFont(GuiResource.getInstance().getFontDefault());
     wAdvancedTab.setText(BaseMessages.getString(PKG, "ActionUnZip.Tab.Advanced.Label"));
 
     Composite wAdvancedComp = new Composite(wTabFolder, SWT.NONE);
-    props.setLook(wAdvancedComp);
+    PropsUi.setLook(wAdvancedComp);
 
     FormLayout advancedLayout = new FormLayout();
     advancedLayout.marginWidth = 3;
@@ -781,7 +791,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // START OF LOGGING GROUP///
     // /
     Group wFileResult = new Group(wAdvancedComp, SWT.SHADOW_NONE);
-    props.setLook(wFileResult);
+    PropsUi.setLook(wFileResult);
     wFileResult.setText(BaseMessages.getString(PKG, "ActionUnZip.FileResult.Group.Label"));
 
     FormLayout groupLayout = new FormLayout();
@@ -794,14 +804,14 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // Add File to result
     Label wlAddFileToResult = new Label(wFileResult, SWT.RIGHT);
     wlAddFileToResult.setText(BaseMessages.getString(PKG, "ActionUnZip.AddFileToResult.Label"));
-    props.setLook(wlAddFileToResult);
+    PropsUi.setLook(wlAddFileToResult);
     FormData fdlAddFileToResult = new FormData();
     fdlAddFileToResult.left = new FormAttachment(0, 0);
     fdlAddFileToResult.top = new FormAttachment(wSource, margin);
     fdlAddFileToResult.right = new FormAttachment(middle, -margin);
     wlAddFileToResult.setLayoutData(fdlAddFileToResult);
     wAddFileToResult = new Button(wFileResult, SWT.CHECK);
-    props.setLook(wAddFileToResult);
+    PropsUi.setLook(wAddFileToResult);
     wAddFileToResult.setToolTipText(
         BaseMessages.getString(PKG, "ActionUnZip.AddFileToResult.Tooltip"));
     FormData fdAddFileToResult = new FormData();
@@ -831,7 +841,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     // START OF SUCCESS ON GROUP///
     // /
     Group wSuccessOn = new Group(wAdvancedComp, SWT.SHADOW_NONE);
-    props.setLook(wSuccessOn);
+    PropsUi.setLook(wSuccessOn);
     wSuccessOn.setText(BaseMessages.getString(PKG, "ActionUnZip.SuccessOn.Group.Label"));
 
     FormLayout successongroupLayout = new FormLayout();
@@ -844,7 +854,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     Label wlSuccessCondition = new Label(wSuccessOn, SWT.RIGHT);
     wlSuccessCondition.setText(
         BaseMessages.getString(PKG, "ActionUnZip.SuccessCondition.Label") + " ");
-    props.setLook(wlSuccessCondition);
+    PropsUi.setLook(wlSuccessCondition);
     FormData fdlSuccessCondition = new FormData();
     fdlSuccessCondition.left = new FormAttachment(0, 0);
     fdlSuccessCondition.right = new FormAttachment(middle, 0);
@@ -857,7 +867,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
         BaseMessages.getString(PKG, "ActionUnZip.SuccessWhenNrErrorsLessThan.Label"));
     wSuccessCondition.select(0); // +1: starts at -1
 
-    props.setLook(wSuccessCondition);
+    PropsUi.setLook(wSuccessCondition);
     FormData fdSuccessCondition = new FormData();
     fdSuccessCondition.left = new FormAttachment(middle, 0);
     fdSuccessCondition.top = new FormAttachment(wFileResult, margin);
@@ -875,7 +885,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     wlNrErrorsLessThan = new Label(wSuccessOn, SWT.RIGHT);
     wlNrErrorsLessThan.setText(
         BaseMessages.getString(PKG, "ActionUnZip.NrBadFormedLessThan.Label") + " ");
-    props.setLook(wlNrErrorsLessThan);
+    PropsUi.setLook(wlNrErrorsLessThan);
     FormData fdlNrErrorsLessThan = new FormData();
     fdlNrErrorsLessThan.left = new FormAttachment(0, 0);
     fdlNrErrorsLessThan.top = new FormAttachment(wSuccessCondition, margin);
@@ -888,7 +898,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
             wSuccessOn,
             SWT.SINGLE | SWT.LEFT | SWT.BORDER,
             BaseMessages.getString(PKG, "ActionUnZip.NrBadFormedLessThan.Tooltip"));
-    props.setLook(wNrErrorsLessThan);
+    PropsUi.setLook(wNrErrorsLessThan);
     wNrErrorsLessThan.addModifyListener(lsMod);
     FormData fdNrErrorsLessThan = new FormData();
     fdNrErrorsLessThan.left = new FormAttachment(middle, 0);
@@ -914,7 +924,7 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
 
     wAdvancedComp.layout();
     wAdvancedTab.setControl(wAdvancedComp);
-    props.setLook(wAdvancedComp);
+    PropsUi.setLook(wAdvancedComp);
 
     // ///////////////////////////////////////////////////////////
     // / END OF Advanced TAB
