@@ -71,6 +71,7 @@ public class ActionWebServiceAvailableDialog extends ActionDialog implements IAc
     Shell parent = getParent();
 
     shell = new Shell(parent, SWT.DIALOG_TRIM | SWT.MIN | SWT.MAX | SWT.RESIZE);
+    shell.setMinimumSize(400, 220);
     PropsUi.setLook(shell);
     WorkflowDialog.setShellImage(shell, action);
 
@@ -89,7 +90,8 @@ public class ActionWebServiceAvailableDialog extends ActionDialog implements IAc
 
     // Filename line
     Label wlName = new Label(shell, SWT.RIGHT);
-    wlName.setText(BaseMessages.getString(PKG, "ActionWebServiceAvailable.Name.Label"));
+    wlName.setText(BaseMessages.getString(PKG, "System.ActionName.Label"));
+    wlName.setToolTipText(BaseMessages.getString(PKG, "System.ActionName.Tooltip"));
     PropsUi.setLook(wlName);
     FormData fdlName = new FormData();
     fdlName.left = new FormAttachment(0, 0);
@@ -188,9 +190,7 @@ public class ActionWebServiceAvailableDialog extends ActionDialog implements IAc
     wCancel.setText(BaseMessages.getString(PKG, "System.Button.Cancel"));
     wCancel.addListener(SWT.Selection, e -> cancel());
     BaseTransformDialog.positionBottomButtons(
-        shell, new Button[] {wOk, wCancel}, margin, wReadTimeOut);
-
-    getData();
+        shell, new Button[] {wOk, wCancel}, margin, null);    getData();
 
     BaseDialog.defaultShellHandling(shell, c -> ok(), c -> cancel());
 
