@@ -26,9 +26,9 @@ import org.apache.hop.core.gui.plugin.GuiPlugin;
 import org.apache.hop.core.row.IValueMeta;
 
 /**
- * Contains Intersystems Cache specific information through static final members
+ * Contains InterSystems Cache specific information through static final members
  */
-@DatabaseMetaPlugin(type = "CACHE", typeDescription = "Intersystems Cache", documentationUrl = "/database/databases/cache.html")
+@DatabaseMetaPlugin(type = "CACHE", typeDescription = "InterSystems Cache", documentationUrl = "/database/databases/cache.html")
 @GuiPlugin(id = "GUI-CacheDatabaseMeta")
 public class CacheDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   @Override
