@@ -97,7 +97,7 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   /** @see IDatabase#getNotFoundTK(boolean) */
   @Override
   public int getNotFoundTK(boolean useAutoIncrement) {
-    if (supportsAutoInc() && useAutoIncrement) {
+    if (isSupportsAutoInc() && useAutoIncrement) {
       return 1;
     }
     return super.getNotFoundTK(useAutoIncrement);
@@ -120,7 +120,7 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
 
   /** @return true if the database supports bitmap indexes */
   @Override
-  public boolean supportsBitmapIndex() {
+  public boolean isSupportsBitmapIndex() {
     return false;
   }
 
@@ -226,7 +226,7 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
         retval += "TIMESTAMP";
         break;
       case IValueMeta.TYPE_BOOLEAN:
-        if (supportsBooleanDataType()) {
+        if (isSupportsBooleanDataType()) {
           retval += "BOOLEAN";
         } else {
           retval += "CHAR(1)";
@@ -293,9 +293,9 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
    *     False if the query needs to be executed first.
    */
   @Override
-  public boolean supportsPreparedStatementMetadataRetrieval() {
+  public boolean isSupportsPreparedStatementMetadataRetrieval() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsPreparedStatementMetadataRetrieval();
+      return databaseDialect.isSupportsPreparedStatementMetadataRetrieval();
     }
     return false;
   }
@@ -465,19 +465,19 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   }
 
   @Override
-  public boolean supportsViews() {
+  public boolean isSupportsViews() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsViews();
+      return databaseDialect.isSupportsViews();
     }
-    return super.supportsViews();
+    return super.isSupportsViews();
   }
 
   @Override
-  public boolean supportsTimeStampToDateConversion() {
+  public boolean isSupportsTimeStampToDateConversion() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsTimeStampToDateConversion();
+      return databaseDialect.isSupportsTimeStampToDateConversion();
     }
-    return super.supportsTimeStampToDateConversion();
+    return super.isSupportsTimeStampToDateConversion();
   }
 
   @Override
@@ -489,11 +489,11 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   }
 
   @Override
-  public boolean supportsAutoGeneratedKeys() {
+  public boolean isSupportsAutoGeneratedKeys() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsAutoGeneratedKeys();
+      return databaseDialect.isSupportsAutoGeneratedKeys();
     }
-    return super.supportsAutoGeneratedKeys();
+    return super.isSupportsAutoGeneratedKeys();
   }
 
   @Override
@@ -513,19 +513,19 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   }
 
   @Override
-  public boolean supportsTimestampDataType() {
+  public boolean isSupportsTimestampDataType() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsTimestampDataType();
+      return databaseDialect.isSupportsTimestampDataType();
     }
-    return super.supportsTimestampDataType();
+    return super.isSupportsTimestampDataType();
   }
 
   @Override
-  public boolean supportsResultSetMetadataRetrievalOnly() {
+  public boolean isSupportsResultSetMetadataRetrievalOnly() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsResultSetMetadataRetrievalOnly();
+      return databaseDialect.isSupportsResultSetMetadataRetrievalOnly();
     }
-    return super.supportsResultSetMetadataRetrievalOnly();
+    return super.isSupportsResultSetMetadataRetrievalOnly();
   }
 
   @Override
@@ -595,11 +595,11 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   }
 
   @Override
-  public boolean supportsNewLinesInSql() {
+  public boolean isSupportsNewLinesInSql() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsNewLinesInSql();
+      return databaseDialect.isSupportsNewLinesInSql();
     }
-    return super.supportsNewLinesInSql();
+    return super.isSupportsNewLinesInSql();
   }
 
   @Override
@@ -619,27 +619,27 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   }
 
   @Override
-  public boolean requiresCastToVariousForIsNull() {
+  public boolean isRequiresCastToVariousForIsNull() {
     if (databaseDialect != null) {
-      return databaseDialect.requiresCastToVariousForIsNull();
+      return databaseDialect.isRequiresCastToVariousForIsNull();
     }
-    return super.requiresCastToVariousForIsNull();
+    return super.isRequiresCastToVariousForIsNull();
   }
 
   @Override
-  public boolean requiresCreateTablePrimaryKeyAppend() {
+  public boolean isRequiresCreateTablePrimaryKeyAppend() {
     if (databaseDialect != null) {
-      return databaseDialect.requiresCreateTablePrimaryKeyAppend();
+      return databaseDialect.isRequiresCreateTablePrimaryKeyAppend();
     }
-    return super.requiresCreateTablePrimaryKeyAppend();
+    return super.isRequiresCreateTablePrimaryKeyAppend();
   }
 
   @Override
-  public boolean supportsSequenceNoMaxValueOption() {
+  public boolean isSupportsSequenceNoMaxValueOption() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsSequenceNoMaxValueOption();
+      return databaseDialect.isSupportsSequenceNoMaxValueOption();
     }
-    return super.supportsSequenceNoMaxValueOption();
+    return super.isSupportsSequenceNoMaxValueOption();
   }
 
   @Override
@@ -723,19 +723,19 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   }
 
   @Override
-  public boolean supportsSetMaxRows() {
+  public boolean isSupportsSetMaxRows() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsSetMaxRows();
+      return databaseDialect.isSupportsSetMaxRows();
     }
-    return super.supportsSetMaxRows();
+    return super.isSupportsSetMaxRows();
   }
 
   @Override
-  public boolean supportsGetBlob() {
+  public boolean isSupportsGetBlob() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsGetBlob();
+      return databaseDialect.isSupportsGetBlob();
     }
-    return super.supportsGetBlob();
+    return super.isSupportsGetBlob();
   }
 
   @Override
@@ -755,11 +755,11 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   }
 
   @Override
-  public boolean preserveReservedCase() {
+  public boolean isPreserveReservedCase() {
     if (databaseDialect != null) {
-      return databaseDialect.preserveReservedCase();
+      return databaseDialect.isPreserveReservedCase();
     }
-    return super.preserveReservedCase();
+    return super.isPreserveReservedCase();
   }
 
   @Override
@@ -771,19 +771,19 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   }
 
   @Override
-  public boolean supportsBooleanDataType() {
+  public boolean isSupportsBooleanDataType() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsBooleanDataType();
+      return databaseDialect.isSupportsBooleanDataType();
     }
-    return super.supportsBooleanDataType();
+    return super.isSupportsBooleanDataType();
   }
 
   @Override
-  public boolean supportsBatchUpdates() {
+  public boolean isSupportsBatchUpdates() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsBatchUpdates();
+      return databaseDialect.isSupportsBatchUpdates();
     }
-    return super.supportsBatchUpdates();
+    return super.isSupportsBatchUpdates();
   }
 
   @Override
@@ -795,19 +795,19 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   }
 
   @Override
-  public boolean supportsFloatRoundingOnUpdate() {
+  public boolean isSupportsFloatRoundingOnUpdate() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsFloatRoundingOnUpdate();
+      return databaseDialect.isSupportsFloatRoundingOnUpdate();
     }
-    return super.supportsFloatRoundingOnUpdate();
+    return super.isSupportsFloatRoundingOnUpdate();
   }
 
   @Override
-  public boolean supportsSynonyms() {
+  public boolean isSupportsSynonyms() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsSynonyms();
+      return databaseDialect.isSupportsSynonyms();
     }
-    return super.supportsSynonyms();
+    return super.isSupportsSynonyms();
   }
 
   @Override
@@ -843,11 +843,11 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   }
 
   @Override
-  public boolean quoteReservedWords() {
+  public boolean isQuoteReservedWords() {
     if (databaseDialect != null) {
-      return databaseDialect.quoteReservedWords();
+      return databaseDialect.isQuoteReservedWords();
     }
-    return super.quoteReservedWords();
+    return super.isQuoteReservedWords();
   }
 
   @Override
@@ -938,11 +938,11 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   }
 
   @Override
-  public boolean supportsOptionsInURL() {
+  public boolean isSupportsOptionsInURL() {
     if (databaseDialect != null) {
-      return databaseDialect.supportsOptionsInURL();
+      return databaseDialect.isSupportsOptionsInURL();
     }
-    return super.supportsOptionsInURL();
+    return super.isSupportsOptionsInURL();
   }
 
   @Override
@@ -954,7 +954,7 @@ public class GenericDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   }
 
   @Override
-  public boolean requiresName() {
+  public boolean isRequiresName() {
     return false;
   }
 }
