@@ -21,7 +21,9 @@ import org.apache.hop.core.database.IDatabase;
 import org.apache.hop.core.util.Utils;
 import org.junit.Test;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
 
 public class SequenceMetaTest {
 
