@@ -49,8 +49,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20000-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      toolTip = "The project ID for your Google Cloud Project.",
-      label = "Project ID")
+      toolTip = "i18n::BeamEnginesDataflow.OptionsProjectID.ToolTip",
+      label = "i18n::BeamEnginesDataflow.OptionsProjectID.Label")
   @HopMetadataProperty
   private String gcpProjectId;
 
@@ -58,8 +58,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20005-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      toolTip = "Run the job as a specific service account, instead of the default GCE robot",
-      label = "Service account")
+      toolTip = "i18n::BeamEnginesDataflow.OptionsServiceAccount.ToolTip",
+      label = "i18n::BeamEnginesDataflow.OptionsServiceAccount.Label")
   @HopMetadataProperty
   private String gcpServiceAccount;
 
@@ -67,9 +67,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20010-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      toolTip =
-          "The name of the Dataflow job being executed as it appears in Dataflow's jobs list and job details",
-      label = "Application name")
+      toolTip = "i18n::BeamEnginesDataflow.OptionsAppName.ToolTip",
+      label = "i18n::BeamEnginesDataflow.OptionsAppName.Label")
   @HopMetadataProperty
   private String gcpAppName;
 
@@ -77,10 +76,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20020-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.FOLDER,
-      toolTip =
-          "Cloud Storage path for staging local files.\n"
-              + "Must be a valid Cloud Storage URL, beginning with gs://",
-      label = "Staging location")
+      toolTip = "i18n::BeamEnginesDataflow.OptionsStagingLocation.ToolTip",
+      label = "i18n::BeamEnginesDataflow.OptionsStagingLocation.Label")
   @HopMetadataProperty
   private String gcpStagingLocation;
 
@@ -88,10 +85,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20030-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      toolTip =
-          "The initial number of Google Compute Engine instances to use when executing your pipeline.\n"
-              + "This option determines how many workers the Dataflow service starts up when your job begins.",
-      label = "Initial number of workers")
+      toolTip = "i18n::BeamEnginesDataflow.OptionsNumberOfWorkers.ToolTip",
+      label = "i18n::BeamEnginesDataflow.OptionsNumberOfWorkers.Label")
   @HopMetadataProperty
   private String gcpInitialNumberOfWorkers;
 
@@ -99,11 +94,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20040-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      label = "Maximum number of workers",
-      toolTip =
-          "The maximum number of workers to use for the workerpool. This options limits the "
-              + "size of the workerpool for the lifetime of the job, including pipeline updates. "
-              + "If left unspecified, the Dataflow service will compute a ceiling.")
+      label = "i18n::BeamEnginesDataflow.OptionsMaxNumberOfWorkers.Label",
+      toolTip = "i18n::BeamEnginesDataflow.OptionsMaxNumberOfWorkers.ToolTip")
   @HopMetadataProperty
   private String gcpMaximumNumberOfWorkers;
 
@@ -111,12 +103,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20050-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      toolTip =
-          "The autoscaling mode for your Dataflow job.\n"
-              + "Possible values are THROUGHPUT_BASED to enable autoscaling, or NONE to disable.\n"
-              + "See https://cloud.google.com/dataflow/service/dataflow-service-desc#Autotuning "
-              + "to learn more about how autoscaling works in the Dataflow managed service.",
-      label = "Auto scaling algorithm")
+      toolTip = "i18n::BeamEnginesDataflow.OptionsAutoScalingAlgorithm.ToolTip",
+      label = "i18n::BeamEnginesDataflow.OptionsAutoScalingAlgorithm.Label")
   @HopMetadataProperty
   private String gcpAutoScalingAlgorithm;
 
@@ -124,19 +112,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20060-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      toolTip =
-          "The Compute Engine machine type that Dataflow uses when starting worker VMs.\n"
-              + "You can use any of the available Compute Engine machine type families as well"
-              + " as custom machine types.\n"
-              + "\n"
-              + "For best results, use n1 machine types.\n"
-              + "Shared core machine types, such as f1 and g1 series workers, are not supported "
-              + "under the Dataflow Service Level Agreement.\n"
-              + "\n"
-              + "Note that Dataflow bills by the number of vCPUs and GB of memory in workers.\n"
-              + "Billing is independent of the machine type family.\n"
-              + "Check https://cloud.google.com/compute/docs/machine-types to see the machine types for reference.",
-      label = "Worker machine type")
+      toolTip = "i18n::BeamEnginesDataflow.OptionsWorkerMachineType.ToolTip",
+      label = "i18n::BeamEnginesDataflow.OptionsWorkerMachineType.Label")
   @HopMetadataProperty
   private String gcpWorkerMachineType;
 
@@ -144,11 +121,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20070-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      toolTip =
-          "The type of persistent disk to use, specified by a full URL of the disk type resource.\n"
-              + "For more information see:\n"
-              + "https://cloud.google.com/compute/docs/disks#pdspecs",
-      label = "Worker disk type")
+      toolTip = "i18n::BeamEnginesDataflow.OptionsWorkerDiskType.ToolTip",
+      label = "i18n::BeamEnginesDataflow.OptionsWorkerDiskType.Label")
   @HopMetadataProperty
   private String gcpWorkerDiskType;
 
@@ -156,10 +130,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20080-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      toolTip =
-          "The disk size, in gigabytes, to use on each remote Compute Engine worker instance.\n"
-              + "If set, specify at least 30 GB to account for the worker boot image and local logs",
-      label = "Disk size in GB")
+      toolTip = "i18n::BeamEnginesDataflow.OptionsDiskSize.ToolTip",
+      label = "i18n::BeamEnginesDataflow.OptionsDiskSize.Label")
   @HopMetadataProperty
   private String gcpDiskSizeGb;
 
@@ -167,17 +139,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20090-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      toolTip =
-          "Specifies a Compute Engine region for launching worker instances to run your pipeline.\n"
-              + "This option is used to run workers in a different location than the region used to deploy, "
-              + "manage, and monitor jobs.\n"
-              + "The zone for workerRegion is "
-              + "https://cloud.google.com/dataflow/docs/concepts/regional-endpoints#autozone.\n"
-              + "\n"
-              + "Note: This option cannot be combined with workerZone or zone.\n"
-              + "\n"
-              + "More information: https://cloud.google.com/dataflow/docs/concepts/regional-endpoints",
-      label = "Region")
+      toolTip = "i18n::BeamEnginesDataflow.OptionsRegion.ToolTip",
+      label = "i18n::BeamEnginesDataflow.OptionsRegion.Label")
   @HopMetadataProperty
   private String gcpRegion;
 
@@ -185,13 +148,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20100-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      toolTip =
-          "Specifies a Compute Engine zone for launching worker instances to run your pipeline.\n"
-              + "This option is used to run workers in a different location than the region used to deploy, "
-              + "manage, and monitor jobs.\n"
-              + "\n"
-              + "Note: This option cannot be combined with workerRegion or zone.",
-      label = "Zone")
+      toolTip = "i18n::BeamEnginesDataflow.OptionsZone.ToolTip",
+      label = "i18n::BeamEnginesDataflow.OptionsZone.Label")
   @HopMetadataProperty
   private String gcpZone;
 
@@ -199,10 +157,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20110-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      label = "Network",
-      toolTip =
-          "GCE network for launching workers. For more information, see the reference documentation "
-              + "https://cloud.google.com/compute/docs/networking. Default is up to the Dataflow service.")
+      label = "i18n::BeamEnginesDataflow.OptionsNetwork.Label",
+      toolTip = "i18n::BeamEnginesDataflow.OptionsNetwork.ToolTip")
   @HopMetadataProperty
   private String gcpNetwork;
 
@@ -210,10 +166,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20120-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      label = "Subnetwork",
-      toolTip =
-          "GCE subnetwork for launching workers. For more information, see the reference documentation "
-              + "https://cloud.google.com/compute/docs/networking. Default is up to the Dataflow service.")
+      label = "i18n::BeamEnginesDataflow.OptionsSubNetwork.Label",
+      toolTip = "i18n::BeamEnginesDataflow.OptionsSubNetwork.ToolTip")
   @HopMetadataProperty
   private String gcpSubnetwork;
 
@@ -221,10 +175,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20130-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.CHECKBOX,
-      label = "Use public IPs?",
-      toolTip =
-          "Specifies whether worker pools should be started with public IP addresses."
-              + "  WARNING: This feature is experimental. You must be allowlisted to use it.")
+      label = "i18n::BeamEnginesDataflow.OptionsPublicIP.Label",
+      toolTip = "i18n::BeamEnginesDataflow.OptionsPublicIP.ToolTip")
   @HopMetadataProperty
   private boolean gcpUsingPublicIps;
 
@@ -232,10 +184,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
       order = "20140-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
       type = GuiElementType.TEXT,
-      label = "Dataflow service options",
-      toolTip =
-          "Comma separated list of service options.  Service options are set by the user and configure the "
-              + "service. This decouples service side feature availability from the Apache Beam release cycle.")
+      label = "i18n::BeamEnginesDataflow.OptionsServiceOptions.Label",
+      toolTip = "i18n::BeamEnginesDataflow.OptionsServiceOptions.ToolTip")
   @HopMetadataProperty
   private String gcpDataflowServiceOptions;
 
@@ -360,8 +310,8 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     // Flag this pipeline as being produced by Apache Hop
     //
     List<String> experiments = options.getExperiments();
-    if (experiments==null) {
-      experiments=new ArrayList<>();
+    if (experiments == null) {
+      experiments = new ArrayList<>();
     } else {
       experiments = new ArrayList<>(experiments);
     }
@@ -389,7 +339,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpProjectId;
   }
 
-  /** @param gcpProjectId The gcpProjectId to set */
+  /**
+   * @param gcpProjectId The gcpProjectId to set
+   */
   public void setGcpProjectId(String gcpProjectId) {
     this.gcpProjectId = gcpProjectId;
   }
@@ -403,7 +355,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpServiceAccount;
   }
 
-  /** @param gcpServiceAccount The GCP service account to set */
+  /**
+   * @param gcpServiceAccount The GCP service account to set
+   */
   public void setGcpServiceAccount(String gcpServiceAccount) {
     this.gcpServiceAccount = gcpServiceAccount;
   }
@@ -417,7 +371,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpAppName;
   }
 
-  /** @param gcpAppName The gcpAppName to set */
+  /**
+   * @param gcpAppName The gcpAppName to set
+   */
   public void setGcpAppName(String gcpAppName) {
     this.gcpAppName = gcpAppName;
   }
@@ -431,7 +387,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpStagingLocation;
   }
 
-  /** @param gcpStagingLocation The gcpStagingLocation to set */
+  /**
+   * @param gcpStagingLocation The gcpStagingLocation to set
+   */
   public void setGcpStagingLocation(String gcpStagingLocation) {
     this.gcpStagingLocation = gcpStagingLocation;
   }
@@ -445,7 +403,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpInitialNumberOfWorkers;
   }
 
-  /** @param gcpInitialNumberOfWorkers The gcpInitialNumberOfWorkers to set */
+  /**
+   * @param gcpInitialNumberOfWorkers The gcpInitialNumberOfWorkers to set
+   */
   public void setGcpInitialNumberOfWorkers(String gcpInitialNumberOfWorkers) {
     this.gcpInitialNumberOfWorkers = gcpInitialNumberOfWorkers;
   }
@@ -459,7 +419,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpMaximumNumberOfWorkers;
   }
 
-  /** @param gcpMaximumNumberOfWorkers The gcpMaximumNumberOfWorkers to set */
+  /**
+   * @param gcpMaximumNumberOfWorkers The gcpMaximumNumberOfWorkers to set
+   */
   public void setGcpMaximumNumberOfWorkers(String gcpMaximumNumberOfWorkers) {
     this.gcpMaximumNumberOfWorkers = gcpMaximumNumberOfWorkers;
   }
@@ -473,7 +435,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpAutoScalingAlgorithm;
   }
 
-  /** @param gcpAutoScalingAlgorithm The gcpAutoScalingAlgorithm to set */
+  /**
+   * @param gcpAutoScalingAlgorithm The gcpAutoScalingAlgorithm to set
+   */
   public void setGcpAutoScalingAlgorithm(String gcpAutoScalingAlgorithm) {
     this.gcpAutoScalingAlgorithm = gcpAutoScalingAlgorithm;
   }
@@ -487,7 +451,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpWorkerMachineType;
   }
 
-  /** @param gcpWorkerMachineType The gcpWorkerMachineType to set */
+  /**
+   * @param gcpWorkerMachineType The gcpWorkerMachineType to set
+   */
   public void setGcpWorkerMachineType(String gcpWorkerMachineType) {
     this.gcpWorkerMachineType = gcpWorkerMachineType;
   }
@@ -501,7 +467,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpWorkerDiskType;
   }
 
-  /** @param gcpWorkerDiskType The gcpWorkerDiskType to set */
+  /**
+   * @param gcpWorkerDiskType The gcpWorkerDiskType to set
+   */
   public void setGcpWorkerDiskType(String gcpWorkerDiskType) {
     this.gcpWorkerDiskType = gcpWorkerDiskType;
   }
@@ -515,7 +483,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpDiskSizeGb;
   }
 
-  /** @param gcpDiskSizeGb The gcpDiskSizeGb to set */
+  /**
+   * @param gcpDiskSizeGb The gcpDiskSizeGb to set
+   */
   public void setGcpDiskSizeGb(String gcpDiskSizeGb) {
     this.gcpDiskSizeGb = gcpDiskSizeGb;
   }
@@ -529,7 +499,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpRegion;
   }
 
-  /** @param gcpRegion The gcpRegion to set */
+  /**
+   * @param gcpRegion The gcpRegion to set
+   */
   public void setGcpRegion(String gcpRegion) {
     this.gcpRegion = gcpRegion;
   }
@@ -543,7 +515,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpZone;
   }
 
-  /** @param gcpZone The gcpZone to set */
+  /**
+   * @param gcpZone The gcpZone to set
+   */
   public void setGcpZone(String gcpZone) {
     this.gcpZone = gcpZone;
   }
@@ -557,7 +531,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpNetwork;
   }
 
-  /** @param gcpNetwork The gcpNetwork to set */
+  /**
+   * @param gcpNetwork The gcpNetwork to set
+   */
   public void setGcpNetwork(String gcpNetwork) {
     this.gcpNetwork = gcpNetwork;
   }
@@ -571,7 +547,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpSubnetwork;
   }
 
-  /** @param gcpSubnetwork The gcpSubnetwork to set */
+  /**
+   * @param gcpSubnetwork The gcpSubnetwork to set
+   */
   public void setGcpSubnetwork(String gcpSubnetwork) {
     this.gcpSubnetwork = gcpSubnetwork;
   }
@@ -585,7 +563,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpUsingPublicIps;
   }
 
-  /** @param gcpUsingPublicIps The gcpUsingPublicIps to set */
+  /**
+   * @param gcpUsingPublicIps The gcpUsingPublicIps to set
+   */
   public void setGcpUsingPublicIps(boolean gcpUsingPublicIps) {
     this.gcpUsingPublicIps = gcpUsingPublicIps;
   }
@@ -599,7 +579,9 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     return gcpDataflowServiceOptions;
   }
 
-  /** @param gcpDataflowServiceOptions The dataflow service options to set */
+  /**
+   * @param gcpDataflowServiceOptions The dataflow service options to set
+   */
   public void setGcpDataflowServiceOptions(String gcpDataflowServiceOptions) {
     this.gcpDataflowServiceOptions = gcpDataflowServiceOptions;
   }
