@@ -27,7 +27,6 @@ import org.apache.beam.sdk.values.KV;
 import org.apache.beam.sdk.values.PCollection;
 import org.apache.hop.beam.core.HopRow;
 import org.apache.hop.beam.core.fn.StaticHopRowFn;
-import org.apache.hop.core.row.JsonRowMeta;
 import org.apache.hop.beam.engines.IBeamPipelineEngineRunConfiguration;
 import org.apache.hop.beam.pipeline.IBeamPipelineTransformHandler;
 import org.apache.hop.core.Const;
@@ -36,6 +35,7 @@ import org.apache.hop.core.RowMetaAndData;
 import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.logging.ILogChannel;
 import org.apache.hop.core.row.IRowMeta;
+import org.apache.hop.core.row.JsonRowMeta;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.pipeline.PipelineMeta;
@@ -70,8 +70,6 @@ public class BeamRowGeneratorTransformHandler extends BeamBaseTransformHandler
       String dataSamplersJson,
       IHopMetadataProvider metadataProvider,
       PipelineMeta pipelineMeta,
-      List<String> transformPluginClasses,
-      List<String> xpPluginClasses,
       TransformMeta transformMeta,
       Map<String, PCollection<HopRow>> transformCollectionMap,
       Pipeline pipeline,
@@ -153,9 +151,7 @@ public class BeamRowGeneratorTransformHandler extends BeamBaseTransformHandler
                       rowDataXml,
                       true,
                       currentTimeFieldIndex,
-                      previousTimeFieldIndex,
-                      transformPluginClasses,
-                      xpPluginClasses)));
+                      previousTimeFieldIndex)));
 
     } else {
 
@@ -198,9 +194,7 @@ public class BeamRowGeneratorTransformHandler extends BeamBaseTransformHandler
                       rowDataXml,
                       false,
                       -1,
-                      -1,
-                      transformPluginClasses,
-                      xpPluginClasses)));
+                      -1)));
     }
 
     transformCollectionMap.put(transformMeta.getName(), afterInput);
