@@ -22,7 +22,6 @@ import org.apache.beam.sdk.values.PCollection;
 import org.apache.commons.lang.StringUtils;
 import org.apache.hop.beam.core.HopRow;
 import org.apache.hop.beam.core.fn.TimestampFn;
-import org.apache.hop.core.row.JsonRowMeta;
 import org.apache.hop.beam.engines.IBeamPipelineEngineRunConfiguration;
 import org.apache.hop.beam.pipeline.IBeamPipelineTransformHandler;
 import org.apache.hop.core.annotations.Transform;
@@ -30,6 +29,7 @@ import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.exception.HopTransformException;
 import org.apache.hop.core.logging.ILogChannel;
 import org.apache.hop.core.row.IRowMeta;
+import org.apache.hop.core.row.JsonRowMeta;
 import org.apache.hop.core.row.value.ValueMetaDate;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.metadata.api.HopMetadataProperty;
@@ -104,8 +104,6 @@ public class BeamTimestampMeta extends BaseTransformMeta<Dummy, DummyData> imple
       String dataSamplersJson,
       IHopMetadataProvider metadataProvider,
       PipelineMeta pipelineMeta,
-      List<String> transformPluginClasses,
-      List<String> xpPluginClasses,
       TransformMeta transformMeta,
       Map<String, PCollection<HopRow>> transformCollectionMap,
       org.apache.beam.sdk.Pipeline pipeline,
@@ -128,9 +126,7 @@ public class BeamTimestampMeta extends BaseTransformMeta<Dummy, DummyData> imple
                     transformMeta.getName(),
                     JsonRowMeta.toJson(rowMeta),
                     variables.resolve(fieldName),
-                    readingTimestamp,
-                    transformPluginClasses,
-                    xpPluginClasses)));
+                    readingTimestamp)));
 
     // Save this in the map
     //
