@@ -47,13 +47,20 @@ import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.metadata.api.IHopMetadataSerializer;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
-import org.apache.hop.testing.*;
+import org.apache.hop.testing.DataSet;
+import org.apache.hop.testing.DataSetField;
+import org.apache.hop.testing.PipelineTweak;
+import org.apache.hop.testing.PipelineUnitTest;
+import org.apache.hop.testing.PipelineUnitTestFieldMapping;
+import org.apache.hop.testing.PipelineUnitTestSetLocation;
+import org.apache.hop.testing.PipelineUnitTestTweak;
 import org.apache.hop.testing.util.DataSetConst;
 import org.apache.hop.testing.xp.PipelineMetaModifier;
 import org.apache.hop.testing.xp.WriteToDataSetExtensionPoint;
 import org.apache.hop.ui.core.dialog.EnterMappingDialog;
 import org.apache.hop.ui.core.dialog.EnterSelectionDialog;
 import org.apache.hop.ui.core.dialog.ErrorDialog;
+import org.apache.hop.ui.core.dialog.MessageBox;
 import org.apache.hop.ui.core.dialog.SelectRowDialog;
 import org.apache.hop.ui.core.metadata.MetadataManager;
 import org.apache.hop.ui.hopgui.HopGui;
@@ -65,7 +72,6 @@ import org.apache.hop.ui.testing.EditRowsDialog;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Control;
-import org.eclipse.swt.widgets.MessageBox;
 
 import java.util.ArrayList;
 import java.util.Collections;
@@ -637,7 +643,7 @@ public class TestingGuiPlugin {
       }
 
       MetadataManager<DataSet> manager =
-          new MetadataManager<>(hopGui.getVariables(), hopGui.getMetadataProvider(), DataSet.class);
+          new MetadataManager<>(hopGui.getVariables(), hopGui.getMetadataProvider(), DataSet.class, hopGui.getShell());
       if (manager.newMetadata(dataSet) != null) {
 
         PipelineUnitTest unitTest = getCurrentUnitTest(pipelineMeta);
@@ -867,7 +873,7 @@ public class TestingGuiPlugin {
 
     MetadataManager<PipelineUnitTest> manager =
         new MetadataManager<>(
-            hopGui.getVariables(), hopGui.getMetadataProvider(), PipelineUnitTest.class);
+            hopGui.getVariables(), hopGui.getMetadataProvider(), PipelineUnitTest.class, hopGui.getShell());
     if (manager.editMetadata(unitTest.getName())) {
       // Activate the test
       refreshUnitTestsList();
@@ -890,7 +896,7 @@ public class TestingGuiPlugin {
 
     MetadataManager<PipelineUnitTest> manager =
         new MetadataManager<>(
-            hopGui.getVariables(), hopGui.getMetadataProvider(), PipelineUnitTest.class);
+            hopGui.getVariables(), hopGui.getMetadataProvider(), PipelineUnitTest.class, hopGui.getShell());
     PipelineUnitTest test = manager.newMetadata();
     if (test != null) {
       // Activate the test
@@ -1008,7 +1014,7 @@ public class TestingGuiPlugin {
     try {
       MetadataManager<PipelineUnitTest> manager =
           new MetadataManager<>(
-              hopGui.getVariables(), hopGui.getMetadataProvider(), PipelineUnitTest.class);
+              hopGui.getVariables(), hopGui.getMetadataProvider(), PipelineUnitTest.class, hopGui.getShell());
       if (manager.editMetadata(unitTestName)) {
         refreshUnitTestsList();
         selectUnitTestInList(unitTestName);
