@@ -31,8 +31,16 @@ import org.apache.hop.metadata.api.HopMetadata;
 import org.apache.hop.metadata.api.HopMetadataBase;
 import org.apache.hop.metadata.api.HopMetadataProperty;
 import org.apache.hop.metadata.api.IHopMetadata;
-import org.neo4j.driver.*;
+import org.neo4j.driver.AuthTokens;
+import org.neo4j.driver.Config;
+import org.neo4j.driver.Driver;
+import org.neo4j.driver.GraphDatabase;
+import org.neo4j.driver.Logging;
 import org.neo4j.driver.Record;
+import org.neo4j.driver.Result;
+import org.neo4j.driver.Session;
+import org.neo4j.driver.SessionConfig;
+import org.neo4j.driver.Value;
 
 import java.net.URI;
 import java.net.URISyntaxException;
@@ -100,9 +108,12 @@ public class NeoConnection extends HopMetadataBase implements IHopMetadata {
 
   @HopMetadataProperty private String automaticVariable;
 
+  @HopMetadataProperty private String protocol;
+
   public NeoConnection() {
     boltPort = "7687";
     browserPort = "7474";
+    protocol = "neo4j";
     manualUrls = new ArrayList<>();
     version4 = true;
     automatic = true;
@@ -132,6 +143,7 @@ public class NeoConnection extends HopMetadataBase implements IHopMetadata {
     this.version4Variable = source.version4Variable;
     this.automatic = source.automatic;
     this.automaticVariable = source.automaticVariable;
+    this.protocol = source.protocol;
     this.manualUrls = new ArrayList<>();
     this.manualUrls.addAll(source.manualUrls);
   }
@@ -222,7 +234,7 @@ public class NeoConnection extends HopMetadataBase implements IHopMetadata {
       //
       List<String> serverStrings = new ArrayList<>();
       String serversString = variables.resolve(server);
-      if (isUsingRouting(variables)) {
+      if (!isAutomatic(variables) && isUsingRouting(variables)) {
         Collections.addAll(serverStrings, serversString.split(","));
       } else {
         serverStrings.add(serversString);
@@ -249,10 +261,14 @@ public class NeoConnection extends HopMetadataBase implements IHopMetadata {
      * bolt+routing://core-server:port/?policy=MyPolicy
      */
     String url = "";
-    if (isAutomatic(variables) || isUsingRouting(variables)) {
-      url += "neo4j";
+    if (StringUtils.isEmpty(protocol)) {
+      if (isAutomatic(variables) || isUsingRouting(variables)) {
+        url += "neo4j";
+      } else {
+        url += "bolt";
+      }
     } else {
-      url += "bolt";
+      url += variables.resolve(protocol);
     }
     url += "://";
 
@@ -795,4 +811,22 @@ public class NeoConnection extends HopMetadataBase implements IHopMetadata {
   public void setAutomaticVariable(String automaticVariable) {
     this.automaticVariable = automaticVariable;
   }
+
+  /**
+   * Gets protocol
+   *
+   * @return value of protocol
+   */
+  public String getProtocol() {
+    return protocol;
+  }
+
+  /**
+   * Sets protocol
+   *
+   * @param protocol value of protocol
+   */
+  public void setProtocol(String protocol) {
+    this.protocol = protocol;
+  }
 }
