@@ -21,7 +21,11 @@ import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.pipeline.transform.BaseTransformData;
 import org.apache.hop.pipeline.transform.ITransformData;
 
-public class ParquetInputData extends BaseTransformData implements ITransformData {
+public class ParquetInputData extends BaseTransformData implements ITransformData {  
   public IRowMeta outputRowMeta;
   public int filenameFieldIndex;
+  
+  public ParquetInputData() {
+    super();
+  }
 }
