@@ -28,6 +28,7 @@ import org.apache.hop.core.row.RowMeta;
 import org.apache.hop.core.row.value.ValueMetaInteger;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.xml.XmlHandler;
+import org.apache.hop.metadata.api.HopMetadataProperty;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
@@ -44,40 +45,35 @@ import java.util.List;
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Transform",
     keywords = "i18n::ClosureGeneratorMeta.keyword",
     documentationUrl = "/pipeline/transforms/closure.html")
-public class ClosureGeneratorMeta extends BaseTransformMeta<ClosureGenerator, ClosureGeneratorData> {
+public class ClosureGeneratorMeta
+    extends BaseTransformMeta<ClosureGenerator, ClosureGeneratorData> {
 
+  @HopMetadataProperty(key = "is_root_zero")
   private boolean rootIdZero;
 
+  @HopMetadataProperty(key = "parent_id_field")
   private String parentIdFieldName;
+
+  @HopMetadataProperty(key = "child_id_field")
   private String childIdFieldName;
+
+  @HopMetadataProperty(key = "distance_field")
   private String distanceFieldName;
 
   public ClosureGeneratorMeta() {
     super();
   }
 
-  @Override
-  public void loadXml(Node transformNode, IHopMetadataProvider metadataProvider)
-      throws HopXmlException {
-    readData(transformNode, metadataProvider);
+  public ClosureGeneratorMeta(ClosureGeneratorMeta m) {
+    this.rootIdZero = m.rootIdZero;
+    this.parentIdFieldName = m.parentIdFieldName;
+    this.childIdFieldName = m.childIdFieldName;
+    this.distanceFieldName = m.distanceFieldName;
   }
 
   @Override
-  public Object clone() {
-    ClosureGeneratorMeta retval = (ClosureGeneratorMeta) super.clone();
-    return retval;
-  }
-
-  private void readData(Node transformNode, IHopMetadataProvider metadataProvider)
-      throws HopXmlException {
-    try {
-      parentIdFieldName = XmlHandler.getTagValue(transformNode, "parent_id_field");
-      childIdFieldName = XmlHandler.getTagValue(transformNode, "child_id_field");
-      distanceFieldName = XmlHandler.getTagValue(transformNode, "distance_field");
-      rootIdZero = "Y".equalsIgnoreCase(XmlHandler.getTagValue(transformNode, "is_root_zero"));
-    } catch (Exception e) {
-      throw new HopXmlException("Unable to load transform info from XML", e);
-    }
+  public ClosureGeneratorMeta clone() {
+    return new ClosureGeneratorMeta(this);
   }
 
   @Override
@@ -119,18 +115,6 @@ public class ClosureGeneratorMeta extends BaseTransformMeta<ClosureGenerator, Cl
     row.addRowMeta(result);
   }
 
-  @Override
-  public String getXml() {
-    StringBuilder retval = new StringBuilder(300);
-
-    retval.append("    ").append(XmlHandler.addTagValue("parent_id_field", parentIdFieldName));
-    retval.append("    ").append(XmlHandler.addTagValue("child_id_field", childIdFieldName));
-    retval.append("    ").append(XmlHandler.addTagValue("distance_field", distanceFieldName));
-    retval.append("    ").append(XmlHandler.addTagValue("is_root_zero", rootIdZero));
-
-    return retval.toString();
-  }
-
   @Override
   public void check(
       List<ICheckResult> remarks,
@@ -179,42 +163,58 @@ public class ClosureGeneratorMeta extends BaseTransformMeta<ClosureGenerator, Cl
     }
   }
 
-  /** @return the rootIdZero */
+  /**
+   * @return the rootIdZero
+   */
   public boolean isRootIdZero() {
     return rootIdZero;
   }
 
-  /** @param rootIdZero the rootIdZero to set */
+  /**
+   * @param rootIdZero the rootIdZero to set
+   */
   public void setRootIdZero(boolean rootIdZero) {
     this.rootIdZero = rootIdZero;
   }
 
-  /** @return the parentIdFieldName */
+  /**
+   * @return the parentIdFieldName
+   */
   public String getParentIdFieldName() {
     return parentIdFieldName;
   }
 
-  /** @param parentIdFieldName the parentIdFieldName to set */
+  /**
+   * @param parentIdFieldName the parentIdFieldName to set
+   */
   public void setParentIdFieldName(String parentIdFieldName) {
     this.parentIdFieldName = parentIdFieldName;
   }
 
-  /** @return the childIdFieldName */
+  /**
+   * @return the childIdFieldName
+   */
   public String getChildIdFieldName() {
     return childIdFieldName;
   }
 
-  /** @param childIdFieldName the childIdFieldName to set */
+  /**
+   * @param childIdFieldName the childIdFieldName to set
+   */
   public void setChildIdFieldName(String childIdFieldName) {
     this.childIdFieldName = childIdFieldName;
   }
 
-  /** @return the distanceFieldName */
+  /**
+   * @return the distanceFieldName
+   */
   public String getDistanceFieldName() {
     return distanceFieldName;
   }
 
-  /** @param distanceFieldName the distanceFieldName to set */
+  /**
+   * @param distanceFieldName the distanceFieldName to set
+   */
   public void setDistanceFieldName(String distanceFieldName) {
     this.distanceFieldName = distanceFieldName;
   }
