@@ -30,6 +30,7 @@ import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
 import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.pipeline.transform.TransformMeta;
+import org.apache.hop.ui.core.ConstUi;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.database.dialog.DatabaseExplorerDialog;
 import org.apache.hop.ui.core.dialog.BaseDialog;
@@ -58,10 +59,7 @@ import org.eclipse.swt.widgets.Text;
 
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.HashMap;
 import java.util.List;
-import java.util.Map;
-import java.util.Set;
 
 public class DeleteDialog extends BaseTransformDialog implements ITransformDialog {
   private static final Class<?> PKG = DeleteMeta.class; // For Translator
@@ -78,7 +76,7 @@ public class DeleteDialog extends BaseTransformDialog implements ITransformDialo
 
   private final DeleteMeta input;
 
-  private final Map<String, Integer> inputFields;
+  private final List<String> inputFields = new ArrayList<>();
 
   private ColumnInfo[] ciKey;
 
@@ -89,7 +87,6 @@ public class DeleteDialog extends BaseTransformDialog implements ITransformDialo
       Shell parent, IVariables variables, Object in, PipelineMeta tr, String sname) {
     super(parent, variables, (BaseTransformMeta) in, tr, sname);
     input = (DeleteMeta) in;
-    inputFields = new HashMap<>();
   }
 
   @Override
@@ -124,7 +121,7 @@ public class DeleteDialog extends BaseTransformDialog implements ITransformDialo
     shell.setText(BaseMessages.getString(PKG, "DeleteDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // THE BUTTONS
     wOk = new Button(shell, SWT.PUSH);
@@ -155,8 +152,7 @@ public class DeleteDialog extends BaseTransformDialog implements ITransformDialo
     wTransformName.setLayoutData(fdTransformName);
 
     // Connection line
-    DatabaseMeta databaseMeta = pipelineMeta.findDatabase(input.getConnection(), variables);
-    wConnection = addConnectionLine(shell, wTransformName, databaseMeta, lsMod);
+    wConnection = addConnectionLine(shell, wTransformName, input.getConnection(), lsMod);
     wConnection.addModifyListener(lsMod);
     wConnection.addSelectionListener(lsSelection);
 
@@ -310,9 +306,8 @@ public class DeleteDialog extends BaseTransformDialog implements ITransformDialo
 
               // Remember these fields...
               for (int i = 0; i < row.size(); i++) {
-                inputFields.put(row.getValueMeta(i).getName(), i);
+                inputFields.add(row.getValueMeta(i).getName());
               }
-
               setComboBoxes();
             } catch (HopException e) {
               logError(BaseMessages.getString(PKG, "System.Dialog.GetFieldsFailed.Message"));
@@ -347,17 +342,7 @@ public class DeleteDialog extends BaseTransformDialog implements ITransformDialo
   protected void setComboBoxes() {
     // Something was changed in the row.
     //
-    final Map<String, Integer> fields = new HashMap<>();
-
-    // Add the currentMeta fields...
-    fields.putAll(inputFields);
-
-    Set<String> keySet = fields.keySet();
-    List<String> entries = new ArrayList<>(keySet);
-
-    String[] fieldNames = entries.toArray(new String[entries.size()]);
-    Const.sortStrings(fieldNames);
-    // Key fields
+    String[] fieldNames = ConstUi.sortFieldNames(inputFields);
     ciKey[2].setComboValues(fieldNames);
     ciKey[3].setComboValues(fieldNames);
   }
@@ -499,17 +484,15 @@ public class DeleteDialog extends BaseTransformDialog implements ITransformDialo
       return;
     }
 
-    // Get the information for the dialog into the input structure.
-    getInfo(input);
-
-    DatabaseMeta databaseMeta = pipelineMeta.findDatabase(input.getConnection(), variables);
-    if (databaseMeta == null) {
+    if (wConnection.getText() == null) {
       MessageBox mb = new MessageBox(shell, SWT.OK | SWT.ICON_ERROR);
       mb.setMessage(BaseMessages.getString(PKG, "DeleteDialog.InvalidConnection.DialogMessage"));
       mb.setText(BaseMessages.getString(PKG, "DeleteDialog.InvalidConnection.DialogTitle"));
       mb.open();
       return;
     }
+    // Get the information for the dialog into the input structure.
+    getInfo(input);
 
     dispose();
   }
