@@ -392,7 +392,7 @@ public class ExecSqlRowDialog extends BaseTransformDialog implements ITransformD
       return;
     }
 
-    if (input.getConnection() == null) {
+    if (wConnection.getText() == null) {
       MessageBox mb = new MessageBox(shell, SWT.OK | SWT.ICON_ERROR);
       mb.setMessage(
               BaseMessages.getString(PKG, "ExecSqlRowDialog.InvalidConnection.DialogMessage"));
