@@ -27,6 +27,7 @@ import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
 import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.pipeline.transform.TransformMeta;
+import org.apache.hop.ui.core.ConstUi;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.ErrorDialog;
@@ -51,10 +52,7 @@ import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.swt.widgets.Text;
 
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.List;
-import java.util.Map;
-import java.util.Set;
 
 public class FieldsChangeSequenceDialog extends BaseTransformDialog implements ITransformDialog {
   private static final Class<?> PKG = FieldsChangeSequenceMeta.class; // For Translator
@@ -69,7 +67,7 @@ public class FieldsChangeSequenceDialog extends BaseTransformDialog implements I
 
   private Text wResult;
 
-  private final Map<String, Integer> inputFields;
+  private final List<String> inputFields = new ArrayList<>();
 
   private ColumnInfo[] colinf;
 
@@ -79,7 +77,6 @@ public class FieldsChangeSequenceDialog extends BaseTransformDialog implements I
       Shell parent, IVariables variables, Object in, PipelineMeta tr, String sname) {
     super(parent, variables, (BaseTransformMeta) in, tr, sname);
     input = (FieldsChangeSequenceMeta) in;
-    inputFields = new HashMap<>();
   }
 
   @Override
@@ -102,7 +99,7 @@ public class FieldsChangeSequenceDialog extends BaseTransformDialog implements I
     shell.setText(BaseMessages.getString(PKG, "FieldsChangeSequenceDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
@@ -241,9 +238,8 @@ public class FieldsChangeSequenceDialog extends BaseTransformDialog implements I
               if (row != null) {
                 // Remember these fields...
                 for (int i = 0; i < row.size(); i++) {
-                  inputFields.put(row.getValueMeta(i).getName(), i);
+                  inputFields.add(row.getValueMeta(i).getName());
                 }
-
                 setComboBoxes();
               }
 
@@ -253,10 +249,9 @@ public class FieldsChangeSequenceDialog extends BaseTransformDialog implements I
                     if (!wFields.isDisposed()) {
                       for (int i = 0; i < wFields.table.getItemCount(); i++) {
                         TableItem it = wFields.table.getItem(i);
-                        if (!Utils.isEmpty(it.getText(1))) {
-                          if (!inputFields.containsKey(it.getText(1))) {
-                            it.setBackground(GuiResource.getInstance().getColorRed());
-                          }
+                        if (!Utils.isEmpty(it.getText(1))
+                            && (!inputFields.contains(it.getText(1)))) {
+                          it.setBackground(GuiResource.getInstance().getColorRed());
                         }
                       }
                     }
@@ -283,17 +278,7 @@ public class FieldsChangeSequenceDialog extends BaseTransformDialog implements I
   protected void setComboBoxes() {
     // Something was changed in the row.
     //
-    final Map<String, Integer> fields = new HashMap<>();
-
-    // Add the currentMeta fields...
-    fields.putAll(inputFields);
-
-    Set<String> keySet = fields.keySet();
-    List<String> entries = new ArrayList<>(keySet);
-
-    String[] fieldNames = entries.toArray(new String[entries.size()]);
-
-    Const.sortStrings(fieldNames);
+    String[] fieldNames = ConstUi.sortFieldNames(inputFields);
     colinf[0].setComboValues(fieldNames);
   }
 
