@@ -17,6 +17,7 @@
 
 package org.apache.hop.pipeline.transforms.filterrows;
 
+import org.apache.commons.lang.StringUtils;
 import org.apache.hop.core.Condition;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.exception.HopException;
@@ -30,6 +31,7 @@ import org.apache.hop.pipeline.transform.BaseTransformMeta;
 import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.pipeline.transform.stream.IStream;
+import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.ErrorDialog;
 import org.apache.hop.ui.core.widget.ConditionEditor;
@@ -63,10 +65,9 @@ public class FilterRowsDialog extends BaseTransformDialog implements ITransformD
 
   public FilterRowsDialog(
       Shell parent, IVariables variables, Object in, PipelineMeta tr, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, tr, sname);
+    super(parent, variables, (BaseTransformMeta<FilterRows, FilterRowsData>) in, tr, sname);
     input = (FilterRowsMeta) in;
-
-    condition = (Condition) input.getCondition().clone();
+    condition = new Condition(input.getCondition());
   }
 
   @Override
@@ -74,27 +75,27 @@ public class FilterRowsDialog extends BaseTransformDialog implements ITransformD
     Shell parent = getParent();
 
     shell = new Shell(parent, SWT.DIALOG_TRIM | SWT.RESIZE | SWT.MIN | SWT.MAX);
-    props.setLook(shell);
+    PropsUi.setLook(shell);
     setShellImage(shell, input);
 
     ModifyListener lsMod = e -> input.setChanged();
     backupChanged = input.hasChanged();
-    backupCondition = (Condition) condition.clone();
+    backupCondition = new Condition(condition);
 
     FormLayout formLayout = new FormLayout();
-    formLayout.marginWidth = Const.FORM_MARGIN;
-    formLayout.marginHeight = Const.FORM_MARGIN;
+    formLayout.marginWidth = PropsUi.getFormMargin();
+    formLayout.marginHeight = PropsUi.getFormMargin();
 
     shell.setLayout(formLayout);
     shell.setText(BaseMessages.getString(PKG, "FilterRowsDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
     wlTransformName.setText(BaseMessages.getString(PKG, "FilterRowsDialog.TransformName.Label"));
-    props.setLook(wlTransformName);
+    PropsUi.setLook(wlTransformName);
     fdlTransformName = new FormData();
     fdlTransformName.left = new FormAttachment(0, 0);
     fdlTransformName.right = new FormAttachment(middle, -margin);
@@ -102,7 +103,7 @@ public class FilterRowsDialog extends BaseTransformDialog implements ITransformD
     wlTransformName.setLayoutData(fdlTransformName);
     wTransformName = new Text(shell, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
     wTransformName.setText(transformName);
-    props.setLook(wTransformName);
+    PropsUi.setLook(wTransformName);
     wTransformName.addModifyListener(lsMod);
     fdTransformName = new FormData();
     fdTransformName.left = new FormAttachment(middle, 0);
@@ -113,14 +114,14 @@ public class FilterRowsDialog extends BaseTransformDialog implements ITransformD
     // Send 'True' data to...
     Label wlTrueTo = new Label(shell, SWT.RIGHT);
     wlTrueTo.setText(BaseMessages.getString(PKG, "FilterRowsDialog.SendTrueTo.Label"));
-    props.setLook(wlTrueTo);
+    PropsUi.setLook(wlTrueTo);
     FormData fdlTrueTo = new FormData();
     fdlTrueTo.left = new FormAttachment(0, 0);
     fdlTrueTo.right = new FormAttachment(middle, -margin);
     fdlTrueTo.top = new FormAttachment(wTransformName, margin);
     wlTrueTo.setLayoutData(fdlTrueTo);
     wTrueTo = new CCombo(shell, SWT.BORDER);
-    props.setLook(wTrueTo);
+    PropsUi.setLook(wTrueTo);
 
     TransformMeta transforminfo = pipelineMeta.findTransform(transformName);
     if (transforminfo != null) {
@@ -140,14 +141,14 @@ public class FilterRowsDialog extends BaseTransformDialog implements ITransformD
     // Send 'False' data to...
     Label wlFalseTo = new Label(shell, SWT.RIGHT);
     wlFalseTo.setText(BaseMessages.getString(PKG, "FilterRowsDialog.SendFalseTo.Label"));
-    props.setLook(wlFalseTo);
+    PropsUi.setLook(wlFalseTo);
     FormData fdlFalseTo = new FormData();
     fdlFalseTo.left = new FormAttachment(0, 0);
     fdlFalseTo.right = new FormAttachment(middle, -margin);
     fdlFalseTo.top = new FormAttachment(wTrueTo, margin);
     wlFalseTo.setLayoutData(fdlFalseTo);
     wFalseTo = new CCombo(shell, SWT.BORDER);
-    props.setLook(wFalseTo);
+    PropsUi.setLook(wFalseTo);
 
     transforminfo = pipelineMeta.findTransform(transformName);
     if (transforminfo != null) {
@@ -166,13 +167,13 @@ public class FilterRowsDialog extends BaseTransformDialog implements ITransformD
 
     Label wlCondition = new Label(shell, SWT.NONE);
     wlCondition.setText(BaseMessages.getString(PKG, "FilterRowsDialog.Condition.Label"));
-    props.setLook(wlCondition);
+    PropsUi.setLook(wlCondition);
     FormData fdlCondition = new FormData();
     fdlCondition.left = new FormAttachment(0, 0);
     fdlCondition.top = new FormAttachment(wFalseTo, margin);
     wlCondition.setLayoutData(fdlCondition);
 
-    IRowMeta inputfields = null;
+    IRowMeta inputfields;
     try {
       inputfields = pipelineMeta.getPrevTransformFields(variables, transformName);
     } catch (HopException ke) {
@@ -242,21 +243,17 @@ public class FilterRowsDialog extends BaseTransformDialog implements ITransformD
       wCondition.goUp();
     } else {
       String trueTransformName = wTrueTo.getText();
-      if (trueTransformName.length() == 0) {
+      if (StringUtils.isEmpty(trueTransformName)) {
         trueTransformName = null;
       }
       String falseTransformName = wFalseTo.getText();
-      if (falseTransformName.length() == 0) {
+      if (StringUtils.isEmpty(falseTransformName)) {
         falseTransformName = null;
       }
 
-      List<IStream> targetStreams = input.getTransformIOMeta().getTargetStreams();
-
-      targetStreams.get(0).setTransformMeta(pipelineMeta.findTransform(trueTransformName));
-      targetStreams.get(1).setTransformMeta(pipelineMeta.findTransform(falseTransformName));
-
       input.setTrueTransformName(trueTransformName);
       input.setFalseTransformName(falseTransformName);
+      input.searchInfoAndTargetTransforms(pipelineMeta.getTransforms());
 
       transformName = wTransformName.getText(); // return value
       input.setCondition(condition);
