@@ -33,10 +33,8 @@ import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.w3c.dom.Node;
 
@@ -45,12 +43,12 @@ import java.util.List;
 @Transform(
     id = "Http",
     image = "http.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.HTTP",
-    description = "i18n::BaseTransform.TypeTooltipDesc.HTTP",
+    name = "i18n::HTTP.Name",
+    description = "i18n::HTTP.Description",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Lookup",
     keywords = "i18n::HttpMeta.keyword",
     documentationUrl = "/pipeline/transforms/http.html")
-public class HttpMeta extends BaseTransformMeta implements ITransformMeta<Http, HttpData> {
+public class HttpMeta extends BaseTransformMeta<Http, HttpData> {
   private static final Class<?> PKG = HttpMeta.class; // For Translator
 
   // the timeout for waiting for data (milliseconds)
@@ -83,6 +81,8 @@ public class HttpMeta extends BaseTransformMeta implements ITransformMeta<Http,
 
   private boolean urlInField;
 
+  private boolean ignoreSsl;
+
   private String urlField;
 
   private String proxyHost;
@@ -219,7 +219,7 @@ public class HttpMeta extends BaseTransformMeta implements ITransformMeta<Http,
   @Override
   public void loadXml(Node transformNode, IHopMetadataProvider metadataProvider)
       throws HopXmlException {
-    readData(transformNode, metadataProvider);
+    readData(transformNode);
   }
 
   public void allocate(int nrargs, int nrqueryparams) {
@@ -313,6 +313,7 @@ public class HttpMeta extends BaseTransformMeta implements ITransformMeta<Http,
 
     retval.append("    ").append(XmlHandler.addTagValue("url", url));
     retval.append("    " + XmlHandler.addTagValue("urlInField", urlInField));
+    retval.append("    " + XmlHandler.addTagValue("ignoreSsl", ignoreSsl));
     retval.append("    " + XmlHandler.addTagValue("urlField", urlField));
     retval.append("    " + XmlHandler.addTagValue("encoding", encoding));
     retval.append("    " + XmlHandler.addTagValue("httpLogin", httpLogin));
@@ -356,13 +357,14 @@ public class HttpMeta extends BaseTransformMeta implements ITransformMeta<Http,
     return retval.toString();
   }
 
-  private void readData(Node transformNode, IHopMetadataProvider metadataProvider)
+  private void readData(Node transformNode)
       throws HopXmlException {
     try {
       int nrargs;
 
       url = XmlHandler.getTagValue(transformNode, "url");
       urlInField = "Y".equalsIgnoreCase(XmlHandler.getTagValue(transformNode, "urlInField"));
+      ignoreSsl = "Y".equalsIgnoreCase(XmlHandler.getTagValue(transformNode, "ignoreSsl"));
       urlField = XmlHandler.getTagValue(transformNode, "urlField");
       encoding = XmlHandler.getTagValue(transformNode, "encoding");
       httpLogin = XmlHandler.getTagValue(transformNode, "httpLogin");
@@ -468,21 +470,6 @@ public class HttpMeta extends BaseTransformMeta implements ITransformMeta<Http,
     remarks.add(cr);
   }
 
-  @Override
-  public Http createTransform(
-      TransformMeta transformMeta,
-      HttpData data,
-      int cnr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new Http(transformMeta, this, data, cnr, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public HttpData getTransformData() {
-    return new HttpData();
-  }
-
   @Override
   public boolean supportsErrorHandling() {
     return true;
@@ -591,4 +578,12 @@ public class HttpMeta extends BaseTransformMeta implements ITransformMeta<Http,
   public void setResponseHeaderFieldName(String responseHeaderFieldName) {
     this.responseHeaderFieldName = responseHeaderFieldName;
   }
+
+  public boolean isIgnoreSsl() {
+    return ignoreSsl;
+  }
+
+  public void setIgnoreSsl(boolean ignoreSsl) {
+    this.ignoreSsl = ignoreSsl;
+  }
 }
