@@ -27,6 +27,7 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
 import org.apache.hop.pipeline.transform.ITransformDialog;
+import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.ErrorDialog;
 import org.apache.hop.ui.core.widget.ColumnInfo;
@@ -42,7 +43,13 @@ import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.layout.FormAttachment;
 import org.eclipse.swt.layout.FormData;
 import org.eclipse.swt.layout.FormLayout;
-import org.eclipse.swt.widgets.*;
+import org.eclipse.swt.widgets.Button;
+import org.eclipse.swt.widgets.Group;
+import org.eclipse.swt.widgets.Label;
+import org.eclipse.swt.widgets.Shell;
+import org.eclipse.swt.widgets.Table;
+import org.eclipse.swt.widgets.TableItem;
+import org.eclipse.swt.widgets.Text;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -91,7 +98,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     Shell parent = getParent();
 
     shell = new Shell(parent, SWT.DIALOG_TRIM | SWT.RESIZE | SWT.MIN | SWT.MAX);
-    props.setLook(shell);
+    PropsUi.setLook(shell);
     setShellImage(shell, input);
 
     ModifyListener lsMod = e -> input.setChanged();
@@ -99,13 +106,13 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     changed = input.hasChanged();
     oldlsMod = lsMod;
     FormLayout formLayout = new FormLayout();
-    formLayout.marginWidth = Const.FORM_MARGIN;
-    formLayout.marginHeight = Const.FORM_MARGIN;
+    formLayout.marginWidth = PropsUi.getFormMargin();
+    formLayout.marginHeight = PropsUi.getFormMargin();
 
     int middle = props.getMiddlePct();
-    margin = props.getMargin();
+    margin = PropsUi.getMargin();
 
-    fieldsRows = input.getFields().length;
+    fieldsRows = input.getFields().size();
 
     shell.setLayout(formLayout);
     shell.setText(BaseMessages.getString(PKG, "IfNullDialog.Shell.Title"));
@@ -125,7 +132,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
     wlTransformName.setText(BaseMessages.getString(PKG, "IfNullDialog.TransformName.Label"));
-    props.setLook(wlTransformName);
+    PropsUi.setLook(wlTransformName);
     fdlTransformName = new FormData();
     fdlTransformName.left = new FormAttachment(0, 0);
     fdlTransformName.right = new FormAttachment(middle, -margin);
@@ -133,7 +140,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     wlTransformName.setLayoutData(fdlTransformName);
     wTransformName = new Text(shell, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
     wTransformName.setText(transformName);
-    props.setLook(wTransformName);
+    PropsUi.setLook(wTransformName);
     wTransformName.addModifyListener(lsMod);
     fdTransformName = new FormData();
     fdTransformName.left = new FormAttachment(middle, 0);
@@ -146,7 +153,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     // ///////////////////////////////
 
     Group wAllFields = new Group(shell, SWT.SHADOW_NONE);
-    props.setLook(wAllFields);
+    PropsUi.setLook(wAllFields);
     wAllFields.setText(BaseMessages.getString(PKG, "IfNullDialog.AllFields.Label"));
 
     FormLayout allFieldsgroupLayout = new FormLayout();
@@ -157,7 +164,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     // Replace by Value
     wlReplaceByValue = new Label(wAllFields, SWT.RIGHT);
     wlReplaceByValue.setText(BaseMessages.getString(PKG, "IfNullDialog.ReplaceByValue.Label"));
-    props.setLook(wlReplaceByValue);
+    PropsUi.setLook(wlReplaceByValue);
     FormData fdlReplaceByValue = new FormData();
     fdlReplaceByValue.left = new FormAttachment(0, 0);
     fdlReplaceByValue.right = new FormAttachment(middle, -margin);
@@ -167,7 +174,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     wReplaceByValue = new TextVar(variables, wAllFields, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
     wReplaceByValue.setToolTipText(
         BaseMessages.getString(PKG, "IfNullDialog.ReplaceByValue.Tooltip"));
-    props.setLook(wReplaceByValue);
+    PropsUi.setLook(wReplaceByValue);
     FormData fdReplaceByValue = new FormData();
     fdReplaceByValue.left = new FormAttachment(middle, 0);
     fdReplaceByValue.top = new FormAttachment(wTransformName, 2 * margin);
@@ -178,7 +185,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     wlSetEmptyStringAll = new Label(wAllFields, SWT.RIGHT);
     wlSetEmptyStringAll.setText(
         BaseMessages.getString(PKG, "IfNullDialog.SetEmptyStringAll.Label"));
-    props.setLook(wlSetEmptyStringAll);
+    PropsUi.setLook(wlSetEmptyStringAll);
     FormData fdlSetEmptyStringAll = new FormData();
     fdlSetEmptyStringAll.left = new FormAttachment(0, 0);
     fdlSetEmptyStringAll.top = new FormAttachment(wReplaceByValue, margin);
@@ -187,7 +194,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     wSetEmptyStringAll = new Button(wAllFields, SWT.CHECK);
     wSetEmptyStringAll.setToolTipText(
         BaseMessages.getString(PKG, "IfNullDialog.SetEmptyStringAll.Tooltip"));
-    props.setLook(wSetEmptyStringAll);
+    PropsUi.setLook(wSetEmptyStringAll);
     FormData fdSetEmptyStringAll = new FormData();
     fdSetEmptyStringAll.left = new FormAttachment(middle, 0);
     fdSetEmptyStringAll.top = new FormAttachment(wlSetEmptyStringAll, 0, SWT.CENTER);
@@ -205,7 +212,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
 
     wlMask = new Label(wAllFields, SWT.RIGHT);
     wlMask.setText(BaseMessages.getString(PKG, "IfNullDialog.Mask.Label"));
-    props.setLook(wlMask);
+    PropsUi.setLook(wlMask);
     FormData fdlMask = new FormData();
     fdlMask.left = new FormAttachment(0, 0);
     fdlMask.top = new FormAttachment(wSetEmptyStringAll, margin);
@@ -214,7 +221,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     wMask = new CCombo(wAllFields, SWT.BORDER | SWT.READ_ONLY);
     wMask.setEditable(true);
     wMask.setItems(Const.getDateFormats());
-    props.setLook(wMask);
+    PropsUi.setLook(wMask);
     wMask.addModifyListener(lsMod);
     FormData fdMask = new FormData();
     fdMask.left = new FormAttachment(middle, 0);
@@ -235,7 +242,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     // Select fields?
     Label wlSelectFields = new Label(shell, SWT.RIGHT);
     wlSelectFields.setText(BaseMessages.getString(PKG, "IfNullDialog.SelectFields.Label"));
-    props.setLook(wlSelectFields);
+    PropsUi.setLook(wlSelectFields);
     FormData fdlSelectFields = new FormData();
     fdlSelectFields.left = new FormAttachment(0, 0);
     fdlSelectFields.top = new FormAttachment(wAllFields, margin);
@@ -243,7 +250,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     wlSelectFields.setLayoutData(fdlSelectFields);
     wSelectFields = new Button(shell, SWT.CHECK);
     wSelectFields.setToolTipText(BaseMessages.getString(PKG, "IfNullDialog.SelectFields.Tooltip"));
-    props.setLook(wSelectFields);
+    PropsUi.setLook(wSelectFields);
     FormData fdSelectFields = new FormData();
     fdSelectFields.left = new FormAttachment(middle, 0);
     fdSelectFields.top = new FormAttachment(wlSelectFields, 0, SWT.CENTER);
@@ -253,7 +260,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     // Select type?
     Label wlSelectValuesType = new Label(shell, SWT.RIGHT);
     wlSelectValuesType.setText(BaseMessages.getString(PKG, "IfNullDialog.SelectValuesType.Label"));
-    props.setLook(wlSelectValuesType);
+    PropsUi.setLook(wlSelectValuesType);
     FormData fdlSelectValuesType = new FormData();
     fdlSelectValuesType.left = new FormAttachment(0, 0);
     fdlSelectValuesType.top = new FormAttachment(wSelectFields, margin);
@@ -262,7 +269,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     wSelectValuesType = new Button(shell, SWT.CHECK);
     wSelectValuesType.setToolTipText(
         BaseMessages.getString(PKG, "IfNullDialog.SelectValuesType.Tooltip"));
-    props.setLook(wSelectValuesType);
+    PropsUi.setLook(wSelectValuesType);
     FormData fdSelectValuesType = new FormData();
     fdSelectValuesType.left = new FormAttachment(middle, 0);
     fdSelectValuesType.top = new FormAttachment(wlSelectValuesType, 0, SWT.CENTER);
@@ -271,13 +278,13 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
 
     wlValueTypes = new Label(shell, SWT.NONE);
     wlValueTypes.setText(BaseMessages.getString(PKG, "IfNullDialog.ValueTypes.Label"));
-    props.setLook(wlValueTypes);
+    PropsUi.setLook(wlValueTypes);
     FormData fdlValueTypes = new FormData();
     fdlValueTypes.left = new FormAttachment(0, 0);
     fdlValueTypes.top = new FormAttachment(wSelectValuesType, margin);
     wlValueTypes.setLayoutData(fdlValueTypes);
 
-    int valueTypesRows = input.getValueTypes().length;
+    int valueTypesRows = input.getValueTypes().size();
 
     ColumnInfo[] colval =
         new ColumnInfo[] {
@@ -358,7 +365,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     // Table with fields
     wlFields = new Label(shell, SWT.NONE);
     wlFields.setText(BaseMessages.getString(PKG, "IfNullDialog.Fields.Label"));
-    props.setLook(wlFields);
+    PropsUi.setLook(wlFields);
     FormData fdlFields = new FormData();
     fdlFields.left = new FormAttachment(0, 0);
     fdlFields.top = new FormAttachment(wValueTypes, margin);
@@ -507,24 +514,25 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     wSelectValuesType.setSelection(input.isSelectValuesType());
 
     Table table = wValueTypes.table;
-    if (input.getValueTypes().length > 0) {
+    if ( !input.getValueTypes().isEmpty() ) {
       table.removeAll();
     }
-    for (int i = 0; i < input.getValueTypes().length; i++) {
+    for (int i = 0; i < input.getValueTypes().size(); i++) {
+      ValueType valueType = input.getValueTypes().get(i);      
       TableItem ti = new TableItem(table, SWT.NONE);
       ti.setText(0, "" + (i + 1));
-      if (input.getValueTypes()[i].getTypeName() != null) {
-        ti.setText(1, input.getValueTypes()[i].getTypeName());
+      if (valueType.getName() != null) {
+        ti.setText(1, valueType.getName());
       }
-      if (input.getValueTypes()[i].getTypereplaceValue() != null) {
-        ti.setText(2, input.getValueTypes()[i].getTypereplaceValue());
+      if (valueType.getValue() != null) {
+        ti.setText(2, valueType.getValue());
       }
-      if (input.getValueTypes()[i].getTypereplaceMask() != null) {
-        ti.setText(3, input.getValueTypes()[i].getTypereplaceMask());
+      if (valueType.getMask() != null) {
+        ti.setText(3, valueType.getMask());
       }
       ti.setText(
           4,
-          input.getValueTypes()[i].isSetTypeEmptyString()
+          valueType.isSetEmptyString()
               ? BaseMessages.getString(PKG, "System.Combo.Yes")
               : BaseMessages.getString(PKG, "System.Combo.No"));
     }
@@ -534,24 +542,25 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     wValueTypes.optWidth(true);
 
     table = wFields.table;
-    if (input.getFields().length > 0) {
+    if (!input.getFields().isEmpty()) {
       table.removeAll();
     }
-    for (int i = 0; i < input.getFields().length; i++) {
+    for (int i = 0; i < input.getFields().size(); i++) {
+      Field field = input.getFields().get(i);
       TableItem ti = new TableItem(table, SWT.NONE);
       ti.setText(0, "" + (i + 1));
-      if (input.getFields()[i].getFieldName() != null) {
-        ti.setText(1, input.getFields()[i].getFieldName());
+      if (field.getName() != null) {
+        ti.setText(1, field.getName());
       }
-      if (input.getFields()[i].getReplaceValue() != null) {
-        ti.setText(2, input.getFields()[i].getReplaceValue());
+      if (field.getValue() != null) {
+        ti.setText(2, field.getValue());
       }
-      if (input.getFields()[i].getReplaceMask() != null) {
-        ti.setText(3, input.getFields()[i].getReplaceMask());
+      if (field.getMask() != null) {
+        ti.setText(3, field.getMask());
       }
       ti.setText(
           4,
-          input.getFields()[i].isSetEmptyString()
+          field.isSetEmptyString()
               ? BaseMessages.getString(PKG, "System.Combo.Yes")
               : BaseMessages.getString(PKG, "System.Combo.No"));
     }
@@ -580,7 +589,7 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
     }
     transformName = wTransformName.getText(); // return value
 
-    input.setEmptyStringAll(wSetEmptyStringAll.getSelection());
+    input.setSetEmptyStringAll(wSetEmptyStringAll.getSelection());
 
     if (wSetEmptyStringAll.getSelection()) {
       input.setReplaceAllByValue("");
@@ -596,36 +605,39 @@ public class IfNullDialog extends BaseTransformDialog implements ITransformDialo
 
     int nrtypes = wValueTypes.nrNonEmpty();
     int nrFields = wFields.nrNonEmpty();
-    input.allocate(nrtypes, nrFields);
-
-    // CHECKSTYLE:Indentation:OFF
+    
+    input.getValueTypes().clear();
     for (int i = 0; i < nrtypes; i++) {
       TableItem ti = wValueTypes.getNonEmpty(i);
-      input.getValueTypes()[i].setTypeName(ti.getText(1));
-      input.getValueTypes()[i].setTypeEmptyString(
+      ValueType valueType = new ValueType();
+      valueType.setName(ti.getText(1));
+      valueType.setSetEmptyString(
           BaseMessages.getString(PKG, "System.Combo.Yes").equalsIgnoreCase(ti.getText(4)));
-      if (input.getValueTypes()[i].isSetTypeEmptyString()) {
-        input.getValueTypes()[i].setTypereplaceValue("");
-        input.getValueTypes()[i].setTypereplaceMask("");
+      if (valueType.isSetEmptyString()) {
+        valueType.setValue("");
+        valueType.setMask("");
       } else {
-        input.getValueTypes()[i].setTypereplaceValue(ti.getText(2));
-        input.getValueTypes()[i].setTypereplaceMask(ti.getText(3));
+        valueType.setValue(ti.getText(2));
+        valueType.setMask(ti.getText(3));
       }
+      input.getValueTypes().add(valueType);
     }
 
-    // CHECKSTYLE:Indentation:OFF
+    input.getFields().clear();
     for (int i = 0; i < nrFields; i++) {
       TableItem ti = wFields.getNonEmpty(i);
-      input.getFields()[i].setFieldName(ti.getText(1));
-      input.getFields()[i].setEmptyString(
+      Field field = new Field();
+      field.setName(ti.getText(1));
+      field.setSetEmptyString(
           BaseMessages.getString(PKG, "System.Combo.Yes").equalsIgnoreCase(ti.getText(4)));
-      if (input.getFields()[i].isSetEmptyString()) {
-        input.getFields()[i].setReplaceValue("");
-        input.getFields()[i].setReplaceMask("");
+      if (field.isSetEmptyString()) {
+        field.setValue("");
+        field.setMask("");
       } else {
-        input.getFields()[i].setReplaceValue(ti.getText(2));
-        input.getFields()[i].setReplaceMask(ti.getText(3));
+        field.setValue(ti.getText(2));
+        field.setMask(ti.getText(3));
       }
+      input.getFields().add(field);
     }
     dispose();
   }
