@@ -28,6 +28,7 @@ import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
 import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.pipeline.transform.TransformMeta;
+import org.apache.hop.ui.core.ConstUi;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.widget.ColumnInfo;
@@ -45,10 +46,7 @@ import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.swt.widgets.Text;
 
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.List;
-import java.util.Map;
-import java.util.Set;
 
 public class JaninoDialog extends BaseTransformDialog implements ITransformDialog {
   private static final Class<?> PKG = JaninoMeta.class; // For Translator
@@ -60,7 +58,7 @@ public class JaninoDialog extends BaseTransformDialog implements ITransformDialo
   private final JaninoMeta currentMeta;
   private final JaninoMeta originalMeta;
 
-  private final Map<String, Integer> inputFields;
+  private final List<String> inputFields = new ArrayList<>();
   private ColumnInfo[] colinf;
 
   public JaninoDialog(
@@ -70,7 +68,6 @@ public class JaninoDialog extends BaseTransformDialog implements ITransformDialo
     // The order here is important... currentMeta is looked at for changes
     currentMeta = (JaninoMeta) in;
     originalMeta = (JaninoMeta) currentMeta.clone();
-    inputFields = new HashMap<>();
   }
 
   @Override
@@ -189,7 +186,7 @@ public class JaninoDialog extends BaseTransformDialog implements ITransformDialo
 
               // Remember these fields...
               for (int i = 0; i < row.size(); i++) {
-                inputFields.put(row.getValueMeta(i).getName(), i);
+                inputFields.add(row.getValueMeta(i).getName());
               }
 
               setComboBoxes();
@@ -216,24 +213,12 @@ public class JaninoDialog extends BaseTransformDialog implements ITransformDialo
   protected void setComboBoxes() {
     // Something was changed in the row.
     //
-    final Map<String, Integer> fields = new HashMap<>();
-
-    // Add the currentMeta fields...
-    fields.putAll(inputFields);
-
     shell
         .getDisplay()
         .syncExec(
             () -> {
               // Add the newly create fields.
-
-              Set<String> keySet = fields.keySet();
-              List<String> entries = new ArrayList<>(keySet);
-
-              String[] fieldNames = entries.toArray(new String[entries.size()]);
-
-              Const.sortStrings(fieldNames);
-
+              String[] fieldNames = ConstUi.sortFieldNames(inputFields);
               colinf[5].setComboValues(fieldNames);
             });
   }
