@@ -19,4 +19,9 @@ package org.apache.hop.pipeline.transforms.recordsfromstream;
 
 import org.apache.hop.pipeline.transforms.rowsfromresult.RowsFromResultData;
 
-public class RecordsFromStreamData extends RowsFromResultData {}
+public class RecordsFromStreamData extends RowsFromResultData {
+
+  public RecordsFromStreamData() {
+    super();
+  }
+}
