@@ -33,11 +33,8 @@ import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransform;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.w3c.dom.Node;
 
@@ -54,13 +51,12 @@ import java.util.Locale;
 @Transform(
     id = "SortRows",
     image = "sortrows.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.SortRows",
-    description = "i18n::BaseTransform.TypeTooltipDesc.SortRows",
+    name = "i18n::SortRows.Name",
+    description = "i18n::SortRows.Description",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Transform",
     keywords = "i18n::SortRowsMeta.keyword",
     documentationUrl = "/pipeline/transforms/sort.html")
-public class SortRowsMeta extends BaseTransformMeta
-    implements ITransformMeta<SortRows, SortRowsData>, Serializable {
+public class SortRowsMeta extends BaseTransformMeta<SortRows, SortRowsData> implements Serializable {
   private static final long serialVersionUID = -9075883720765645655L;
   private static final Class<?> PKG = SortRowsMeta.class; // For Translator
 
@@ -197,16 +193,6 @@ public class SortRowsMeta extends BaseTransformMeta
     return retval;
   }
 
-  @Override
-  public ITransform createTransform(
-      TransformMeta transformMeta,
-      SortRowsData data,
-      int copyNr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new SortRows(transformMeta, this, data, copyNr, pipelineMeta, pipeline);
-  }
-
   private void readData(Node transformNode) throws HopXmlException {
     try {
       directory = XmlHandler.getTagValue(transformNode, "directory");
@@ -478,11 +464,6 @@ public class SortRowsMeta extends BaseTransformMeta
     }
   }
 
-  @Override
-  public SortRowsData getTransformData() {
-    return new SortRowsData();
-  }
-
   /** @return Returns the sortSize. */
   public String getSortSize() {
     return sortSize;
