@@ -17,6 +17,9 @@
 
 package org.apache.hop.pipeline.transforms.vertica.bulkloader;
 
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.List;
 import org.apache.hop.core.*;
 import org.apache.hop.core.annotations.Transform;
 import org.apache.hop.core.database.Database;
@@ -24,17 +27,11 @@ import org.apache.hop.core.database.DatabaseMeta;
 import org.apache.hop.core.exception.HopDatabaseException;
 import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.exception.HopTransformException;
-import org.apache.hop.core.exception.HopXmlException;
-import org.apache.hop.core.injection.AfterInjection;
-import org.apache.hop.core.injection.Injection;
-import org.apache.hop.core.injection.InjectionSupported;
 import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.core.row.IValueMeta;
 import org.apache.hop.core.row.RowMeta;
 import org.apache.hop.core.util.StringUtil;
-import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
-import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.HopMetadataProperty;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
@@ -43,12 +40,6 @@ import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
 import org.apache.hop.pipeline.transform.ITransformData;
 import org.apache.hop.pipeline.transform.TransformMeta;
-import org.w3c.dom.Node;
-
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collections;
-import java.util.List;
 
 @Transform(
     id = "VerticaBulkLoader",
@@ -57,113 +48,103 @@ import java.util.List;
     description = "i18n::BaseTransform.TypeTooltipDesc.VerticaBulkLoaderMessage",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Bulk",
     documentationUrl =
-        "https://hop.apache.org/manual/latest/plugins/transforms/verticabulkloader.html")
+        "https://hop.apache.org/manual/latest/plugins/transforms/verticabulkloader.html",
+    isIncludeJdbcDrivers = true,
+    classLoaderGroup = "vertica5")
 public class VerticaBulkLoaderMeta
     extends BaseTransformMeta<VerticaBulkLoader, VerticaBulkLoaderData>
     implements IProvidesModelerMeta {
   private static final Class<?> PKG = VerticaBulkLoaderMeta.class;
 
   @HopMetadataProperty(
-    key = "connection",
-    injectionKey = "CONNECTIONNAME",
-    injectionKeyDescription = "VerticaBulkLoader.Injection.CONNECTIONNAME"
-  )
+      key = "connection",
+      injectionKey = "CONNECTIONNAME",
+      injectionKeyDescription = "VerticaBulkLoader.Injection.CONNECTIONNAME")
   private String connection;
 
   @HopMetadataProperty(
-    key = "schema",
-    injectionKey = "SCHEMANAME",
-    injectionKeyDescription = "VerticaBulkLoader.Injection.SCHEMANAME"
-  )
+      key = "schema",
+      injectionKey = "SCHEMANAME",
+      injectionKeyDescription = "VerticaBulkLoader.Injection.SCHEMANAME")
   private String schemaName;
 
   @HopMetadataProperty(
-    key = "table",
-    injectionKey = "TABLENAME",
-    injectionKeyDescription = "VerticaBulkLoader.Injection.TABLENAME"
-  )
+      key = "table",
+      injectionKey = "TABLENAME",
+      injectionKeyDescription = "VerticaBulkLoader.Injection.TABLENAME")
   private String tablename;
 
   @HopMetadataProperty(
-          key = "truncate",
-          injectionKey = "TRUNCATE_TABLE",
-          injectionKeyDescription = "VerticaBulkLoader.Injection.TruncateTable.Field")
+      key = "truncate",
+      injectionKey = "TRUNCATE_TABLE",
+      injectionKeyDescription = "VerticaBulkLoader.Injection.TruncateTable.Field")
   private boolean truncateTable;
 
   @HopMetadataProperty(
-          key = "only_when_have_rows",
-          injectionKey = "ONLY_WHEN_HAVE_ROWS",
-          injectionKeyDescription = "VerticaBulkLoader.Inject.OnlyWhenHaveRows.Field")
+      key = "only_when_have_rows",
+      injectionKey = "ONLY_WHEN_HAVE_ROWS",
+      injectionKeyDescription = "VerticaBulkLoader.Inject.OnlyWhenHaveRows.Field")
   private boolean onlyWhenHaveRows;
+
   @HopMetadataProperty(
-    key = "direct",
-    injectionKey = "DIRECT",
-    injectionKeyDescription = "VerticaBulkLoader.Injection.DIRECT"
-  )
+      key = "direct",
+      injectionKey = "DIRECT",
+      injectionKeyDescription = "VerticaBulkLoader.Injection.DIRECT")
   private boolean direct = true;
 
   @HopMetadataProperty(
-    key = "abort_on_error",
-    injectionKey = "ABORTONERROR",
-    injectionKeyDescription = "VerticaBulkLoader.Injection.ABORTONERROR"
-  )
+      key = "abort_on_error",
+      injectionKey = "ABORTONERROR",
+      injectionKeyDescription = "VerticaBulkLoader.Injection.ABORTONERROR")
   private boolean abortOnError = true;
 
   @HopMetadataProperty(
-    key = "exceptions_filename",
-    injectionKey = "EXCEPTIONSFILENAME",
-    injectionKeyDescription = "VerticaBulkLoader.Injection.EXCEPTIONSFILENAME"
-  )
+      key = "exceptions_filename",
+      injectionKey = "EXCEPTIONSFILENAME",
+      injectionKeyDescription = "VerticaBulkLoader.Injection.EXCEPTIONSFILENAME")
   private String exceptionsFileName;
 
   @HopMetadataProperty(
-    key = "rejected_data_filename",
-    injectionKey = "REJECTEDDATAFILENAME",
-    injectionKeyDescription = "VerticaBulkLoader.Injection.REJECTEDDATAFILENAME"
-  )
+      key = "rejected_data_filename",
+      injectionKey = "REJECTEDDATAFILENAME",
+      injectionKeyDescription = "VerticaBulkLoader.Injection.REJECTEDDATAFILENAME")
   private String rejectedDataFileName;
 
   @HopMetadataProperty(
-    key = "stream_name",
-    injectionKey = "STREAMNAME",
-    injectionKeyDescription = "VerticaBulkLoader.Injection.STREAMNAME"
-  )
+      key = "stream_name",
+      injectionKey = "STREAMNAME",
+      injectionKeyDescription = "VerticaBulkLoader.Injection.STREAMNAME")
   private String streamName;
 
   /** Do we explicitly select the fields to update in the database */
-  @HopMetadataProperty(
-    key = "specify_fields",
-    injectionKeyDescription = ""
-  )
+  @HopMetadataProperty(key = "specify_fields", injectionKeyDescription = "")
   private boolean specifyFields;
 
   @HopMetadataProperty(
-    groupKey = "fields",
-    key = "field",
-    injectionGroupKey = "FIELDS",
-    injectionGroupDescription = "VerticaBulkLoader.Injection.FIELDS",
-    injectionKey = "FIELDSTREAM",
-    injectionKeyDescription = "VerticaBulkLoader.Injection.FIELDSTREAM"
-  )
-/**
- * Fields containing the values in the input stream to insert
- * */
+      groupKey = "fields",
+      key = "field",
+      injectionGroupKey = "FIELDS",
+      injectionGroupDescription = "VerticaBulkLoader.Injection.FIELDS",
+      injectionKey = "FIELDSTREAM",
+      injectionKeyDescription = "VerticaBulkLoader.Injection.FIELDSTREAM")
+  /** Fields containing the values in the input stream to insert */
   private List<VerticaBulkLoaderField> fields;
 
-  public List<VerticaBulkLoaderField> getFields(){ return fields;}
+  public List<VerticaBulkLoaderField> getFields() {
+    return fields;
+  }
 
-  public void setFields(List<VerticaBulkLoaderField> fields){
+  public void setFields(List<VerticaBulkLoaderField> fields) {
     this.fields = fields;
   }
 
   @HopMetadataProperty(
-    groupKey = "fields",
-    key = "field",
-    injectionGroupKey = "FIELDS",
-    injectionGroupDescription = "VerticaBulkLoader.Injection.FIELDS",
-    injectionKey = "FIELDDATABASE",
-    injectionKeyDescription = "VerticaBulkLoader.Injection.FIELDDATABASE"
-  )
+      groupKey = "fields",
+      key = "field",
+      injectionGroupKey = "FIELDS",
+      injectionGroupDescription = "VerticaBulkLoader.Injection.FIELDS",
+      injectionKey = "FIELDDATABASE",
+      injectionKeyDescription = "VerticaBulkLoader.Injection.FIELDDATABASE")
   /** Fields in the table to insert */
   private String[] fieldDatabase;
 
@@ -180,21 +161,22 @@ public class VerticaBulkLoaderMeta
   /**
    * @return returns the database connection name
    */
-  public String getConnection(){
+  public String getConnection() {
     return connection;
   }
 
   /**
    * sets the database connection name
+   *
    * @param connection the database connection name to set
    */
-  public void setConnection(String connection){
+  public void setConnection(String connection) {
     this.connection = connection;
   }
 
-/*
-  */
-/**
+  /*
+   */
+  /**
    * @return Returns the database.
    */
   public DatabaseMeta getDatabaseMeta() {
@@ -250,7 +232,6 @@ public class VerticaBulkLoaderMeta
     this.onlyWhenHaveRows = onlyWhenHaveRows;
   }
 
-
   /**
    * @param specifyFields The specify fields flag to set.
    */
@@ -330,17 +311,17 @@ public class VerticaBulkLoaderMeta
 
     Database db = null;
 
-    try{
+    try {
 
       DatabaseMeta databaseMeta =
-              metadataProvider.getSerializer(DatabaseMeta.class).load(variables.resolve(connection));
+          metadataProvider.getSerializer(DatabaseMeta.class).load(variables.resolve(connection));
 
       if (databaseMeta != null) {
         CheckResult cr =
-                new CheckResult(
-                        ICheckResult.TYPE_RESULT_OK,
-                        BaseMessages.getString(PKG, "VerticaBulkLoaderMeta.CheckResult.ConnectionExists"),
-                        transformMeta);
+            new CheckResult(
+                ICheckResult.TYPE_RESULT_OK,
+                BaseMessages.getString(PKG, "VerticaBulkLoaderMeta.CheckResult.ConnectionExists"),
+                transformMeta);
         remarks.add(cr);
 
         db = new Database(loggingObject, variables, databaseMeta);
@@ -349,36 +330,36 @@ public class VerticaBulkLoaderMeta
           db.connect();
 
           cr =
-                  new CheckResult(
-                          ICheckResult.TYPE_RESULT_OK,
-                          BaseMessages.getString(PKG, "VerticaBulkLoaderMeta.CheckResult.ConnectionOk"),
-                          transformMeta);
+              new CheckResult(
+                  ICheckResult.TYPE_RESULT_OK,
+                  BaseMessages.getString(PKG, "VerticaBulkLoaderMeta.CheckResult.ConnectionOk"),
+                  transformMeta);
           remarks.add(cr);
 
           if (!StringUtil.isEmpty(tablename)) {
             String schemaTable =
-                    databaseMeta.getQuotedSchemaTableCombination(
-                            variables, db.resolve(schemaName), db.resolve(tablename));
+                databaseMeta.getQuotedSchemaTableCombination(
+                    variables, db.resolve(schemaName), db.resolve(tablename));
             // Check if this table exists...
             String realSchemaName = db.resolve(schemaName);
             String realTableName = db.resolve(tablename);
             if (db.checkTableExists(realSchemaName, realTableName)) {
               cr =
-                      new CheckResult(
-                              ICheckResult.TYPE_RESULT_OK,
-                              BaseMessages.getString(
-                                      PKG, "VerticaBulkLoaderMeta.CheckResult.TableAccessible", schemaTable),
-                              transformMeta);
+                  new CheckResult(
+                      ICheckResult.TYPE_RESULT_OK,
+                      BaseMessages.getString(
+                          PKG, "VerticaBulkLoaderMeta.CheckResult.TableAccessible", schemaTable),
+                      transformMeta);
               remarks.add(cr);
 
               IRowMeta r = db.getTableFields(schemaTable);
               if (r != null) {
                 cr =
-                        new CheckResult(
-                                ICheckResult.TYPE_RESULT_OK,
-                                BaseMessages.getString(
-                                        PKG, "VerticaBulkLoaderMeta.CheckResult.TableOk", schemaTable),
-                                transformMeta);
+                    new CheckResult(
+                        ICheckResult.TYPE_RESULT_OK,
+                        BaseMessages.getString(
+                            PKG, "VerticaBulkLoaderMeta.CheckResult.TableOk", schemaTable),
+                        transformMeta);
                 remarks.add(cr);
 
                 String error_message = "";
@@ -387,13 +368,13 @@ public class VerticaBulkLoaderMeta
                 // Now see what we can find as previous transform...
                 if (prev != null && prev.size() > 0) {
                   cr =
-                          new CheckResult(
-                                  ICheckResult.TYPE_RESULT_OK,
-                                  BaseMessages.getString(
-                                          PKG,
-                                          "VerticaBulkLoaderMeta.CheckResult.FieldsReceived",
-                                          "" + prev.size()),
-                                  transformMeta);
+                      new CheckResult(
+                          ICheckResult.TYPE_RESULT_OK,
+                          BaseMessages.getString(
+                              PKG,
+                              "VerticaBulkLoaderMeta.CheckResult.FieldsReceived",
+                              "" + prev.size()),
+                          transformMeta);
                   remarks.add(cr);
 
                   if (!specifyFields()) {
@@ -403,28 +384,28 @@ public class VerticaBulkLoaderMeta
                       int idx = r.indexOfValue(pv.getName());
                       if (idx < 0) {
                         error_message +=
-                                "\t\t" + pv.getName() + " (" + pv.getTypeDesc() + ")" + Const.CR;
+                            "\t\t" + pv.getName() + " (" + pv.getTypeDesc() + ")" + Const.CR;
                         error_found = true;
                       }
                     }
                     if (error_found) {
                       error_message =
-                              BaseMessages.getString(
-                                      PKG,
-                                      "VerticaBulkLoaderMeta.CheckResult.FieldsNotFoundInOutput",
-                                      error_message);
+                          BaseMessages.getString(
+                              PKG,
+                              "VerticaBulkLoaderMeta.CheckResult.FieldsNotFoundInOutput",
+                              error_message);
 
                       cr =
-                              new CheckResult(
-                                      ICheckResult.TYPE_RESULT_ERROR, error_message, transformMeta);
+                          new CheckResult(
+                              ICheckResult.TYPE_RESULT_ERROR, error_message, transformMeta);
                       remarks.add(cr);
                     } else {
                       cr =
-                              new CheckResult(
-                                      ICheckResult.TYPE_RESULT_OK,
-                                      BaseMessages.getString(
-                                              PKG, "VerticaBulkLoaderMeta.CheckResult.AllFieldsFoundInOutput"),
-                                      transformMeta);
+                          new CheckResult(
+                              ICheckResult.TYPE_RESULT_OK,
+                              BaseMessages.getString(
+                                  PKG, "VerticaBulkLoaderMeta.CheckResult.AllFieldsFoundInOutput"),
+                              transformMeta);
                       remarks.add(cr);
                     }
                   } else {
@@ -438,22 +419,22 @@ public class VerticaBulkLoaderMeta
                     }
                     if (error_found) {
                       error_message =
-                              BaseMessages.getString(
-                                      PKG,
-                                      "VerticaBulkLoaderMeta.CheckResult.FieldsSpecifiedNotInTable",
-                                      error_message);
+                          BaseMessages.getString(
+                              PKG,
+                              "VerticaBulkLoaderMeta.CheckResult.FieldsSpecifiedNotInTable",
+                              error_message);
 
                       cr =
-                              new CheckResult(
-                                      ICheckResult.TYPE_RESULT_ERROR, error_message, transformMeta);
+                          new CheckResult(
+                              ICheckResult.TYPE_RESULT_ERROR, error_message, transformMeta);
                       remarks.add(cr);
                     } else {
                       cr =
-                              new CheckResult(
-                                      ICheckResult.TYPE_RESULT_OK,
-                                      BaseMessages.getString(
-                                              PKG, "VerticaBulkLoaderMeta.CheckResult.AllFieldsFoundInOutput"),
-                                      transformMeta);
+                          new CheckResult(
+                              ICheckResult.TYPE_RESULT_OK,
+                              BaseMessages.getString(
+                                  PKG, "VerticaBulkLoaderMeta.CheckResult.AllFieldsFoundInOutput"),
+                              transformMeta);
                       remarks.add(cr);
                     }
                   }
@@ -466,26 +447,28 @@ public class VerticaBulkLoaderMeta
                       int idx = prev.indexOfValue(rv.getName());
                       if (idx < 0) {
                         error_message +=
-                                "\t\t" + rv.getName() + " (" + rv.getTypeDesc() + ")" + Const.CR;
+                            "\t\t" + rv.getName() + " (" + rv.getTypeDesc() + ")" + Const.CR;
                         error_found = true;
                       }
                     }
                     if (error_found) {
                       error_message =
-                              BaseMessages.getString(
-                                      PKG, "VerticaBulkLoaderMeta.CheckResult.FieldsNotFound", error_message);
+                          BaseMessages.getString(
+                              PKG,
+                              "VerticaBulkLoaderMeta.CheckResult.FieldsNotFound",
+                              error_message);
 
                       cr =
-                              new CheckResult(
-                                      ICheckResult.TYPE_RESULT_WARNING, error_message, transformMeta);
+                          new CheckResult(
+                              ICheckResult.TYPE_RESULT_WARNING, error_message, transformMeta);
                       remarks.add(cr);
                     } else {
                       cr =
-                              new CheckResult(
-                                      ICheckResult.TYPE_RESULT_OK,
-                                      BaseMessages.getString(
-                                              PKG, "VerticaBulkLoaderMeta.CheckResult.AllFieldsFound"),
-                                      transformMeta);
+                          new CheckResult(
+                              ICheckResult.TYPE_RESULT_OK,
+                              BaseMessages.getString(
+                                  PKG, "VerticaBulkLoaderMeta.CheckResult.AllFieldsFound"),
+                              transformMeta);
                       remarks.add(cr);
                     }
                   } else {
@@ -500,85 +483,86 @@ public class VerticaBulkLoaderMeta
                     }
                     if (error_found) {
                       error_message =
-                              BaseMessages.getString(
-                                      PKG,
-                                      "VerticaBulkLoaderMeta.CheckResult.FieldsSpecifiedNotFound",
-                                      error_message);
+                          BaseMessages.getString(
+                              PKG,
+                              "VerticaBulkLoaderMeta.CheckResult.FieldsSpecifiedNotFound",
+                              error_message);
 
                       cr =
-                              new CheckResult(
-                                      ICheckResult.TYPE_RESULT_ERROR, error_message, transformMeta);
+                          new CheckResult(
+                              ICheckResult.TYPE_RESULT_ERROR, error_message, transformMeta);
                       remarks.add(cr);
                     } else {
                       cr =
-                              new CheckResult(
-                                      ICheckResult.TYPE_RESULT_OK,
-                                      BaseMessages.getString(
-                                              PKG, "VerticaBulkLoaderMeta.CheckResult.AllFieldsFound"),
-                                      transformMeta);
+                          new CheckResult(
+                              ICheckResult.TYPE_RESULT_OK,
+                              BaseMessages.getString(
+                                  PKG, "VerticaBulkLoaderMeta.CheckResult.AllFieldsFound"),
+                              transformMeta);
                       remarks.add(cr);
                     }
                   }
                 } else {
                   cr =
-                          new CheckResult(
-                                  ICheckResult.TYPE_RESULT_ERROR,
-                                  BaseMessages.getString(PKG, "VerticaBulkLoaderMeta.CheckResult.NoFields"),
-                                  transformMeta);
+                      new CheckResult(
+                          ICheckResult.TYPE_RESULT_ERROR,
+                          BaseMessages.getString(PKG, "VerticaBulkLoaderMeta.CheckResult.NoFields"),
+                          transformMeta);
                   remarks.add(cr);
                 }
               } else {
                 cr =
-                        new CheckResult(
-                                ICheckResult.TYPE_RESULT_ERROR,
-                                BaseMessages.getString(
-                                        PKG, "VerticaBulkLoaderMeta.CheckResult.TableNotAccessible"),
-                                transformMeta);
+                    new CheckResult(
+                        ICheckResult.TYPE_RESULT_ERROR,
+                        BaseMessages.getString(
+                            PKG, "VerticaBulkLoaderMeta.CheckResult.TableNotAccessible"),
+                        transformMeta);
                 remarks.add(cr);
               }
             } else {
               cr =
-                      new CheckResult(
-                              ICheckResult.TYPE_RESULT_ERROR,
-                              BaseMessages.getString(
-                                      PKG, "VerticaBulkLoaderMeta.CheckResult.TableError", schemaTable),
-                              transformMeta);
+                  new CheckResult(
+                      ICheckResult.TYPE_RESULT_ERROR,
+                      BaseMessages.getString(
+                          PKG, "VerticaBulkLoaderMeta.CheckResult.TableError", schemaTable),
+                      transformMeta);
               remarks.add(cr);
             }
           } else {
             cr =
-                    new CheckResult(
-                            ICheckResult.TYPE_RESULT_ERROR,
-                            BaseMessages.getString(PKG, "VerticaBulkLoaderMeta.CheckResult.NoTableName"),
-                            transformMeta);
+                new CheckResult(
+                    ICheckResult.TYPE_RESULT_ERROR,
+                    BaseMessages.getString(PKG, "VerticaBulkLoaderMeta.CheckResult.NoTableName"),
+                    transformMeta);
             remarks.add(cr);
           }
         } catch (HopException e) {
           cr =
-                  new CheckResult(
-                          ICheckResult.TYPE_RESULT_ERROR,
-                          BaseMessages.getString(
-                                  PKG, "VerticaBulkLoaderMeta.CheckResult.UndefinedError", e.getMessage()),
-                          transformMeta);
+              new CheckResult(
+                  ICheckResult.TYPE_RESULT_ERROR,
+                  BaseMessages.getString(
+                      PKG, "VerticaBulkLoaderMeta.CheckResult.UndefinedError", e.getMessage()),
+                  transformMeta);
           remarks.add(cr);
         } finally {
           db.disconnect();
         }
       } else {
         CheckResult cr =
-                new CheckResult(
-                        ICheckResult.TYPE_RESULT_ERROR,
-                        BaseMessages.getString(PKG, "VerticaBulkLoaderMeta.CheckResult.NoConnection"),
-                        transformMeta);
+            new CheckResult(
+                ICheckResult.TYPE_RESULT_ERROR,
+                BaseMessages.getString(PKG, "VerticaBulkLoaderMeta.CheckResult.NoConnection"),
+                transformMeta);
         remarks.add(cr);
       }
-    }catch(HopException e){
-      CheckResult cr = new CheckResult(
+    } catch (HopException e) {
+      CheckResult cr =
+          new CheckResult(
               ICheckResult.TYPE_RESULT_ERROR,
               BaseMessages.getString(
-                      PKG, "VerticaBulkLoaderMeta.CheckResult.UndefinedError", e.getMessage()),
+                  PKG, "VerticaBulkLoaderMeta.CheckResult.UndefinedError", e.getMessage()),
               transformMeta);
-        remarks.add(cr);
+      remarks.add(cr);
     }
 
     // See if we have input streams leading to this transform!
@@ -608,32 +592,35 @@ public class VerticaBulkLoaderMeta
       String[] input,
       String[] output,
       IRowMeta info,
-      IHopMetadataProvider metadataProvider) throws HopTransformException{
+      IHopMetadataProvider metadataProvider)
+      throws HopTransformException {
 
-    try{
-      DatabaseMeta databaseMeta = metadataProvider.getSerializer(DatabaseMeta.class).load(variables.resolve(connection));
+    try {
+      DatabaseMeta databaseMeta =
+          metadataProvider.getSerializer(DatabaseMeta.class).load(variables.resolve(connection));
 
       // The values that are entering this transform are in "prev":
       if (prev != null) {
         for (int i = 0; i < prev.size(); i++) {
           IValueMeta v = prev.getValueMeta(i);
           DatabaseImpact ii =
-                  new DatabaseImpact(
-                          DatabaseImpact.TYPE_IMPACT_WRITE,
-                          pipelineMeta.getName(),
-                          transformMeta.getName(),
-                          databaseMeta.getDatabaseName(),
-                          tablename,
-                          v.getName(),
-                          v.getName(),
-                          v != null ? v.getOrigin() : "?",
-                          "",
-                          "Type = " + v.toStringMeta());
+              new DatabaseImpact(
+                  DatabaseImpact.TYPE_IMPACT_WRITE,
+                  pipelineMeta.getName(),
+                  transformMeta.getName(),
+                  databaseMeta.getDatabaseName(),
+                  tablename,
+                  v.getName(),
+                  v.getName(),
+                  v != null ? v.getOrigin() : "?",
+                  "",
+                  "Type = " + v.toStringMeta());
           impact.add(ii);
         }
       }
-    }catch(HopException e){
-      throw new HopTransformException("Unable to get databaseMeta for connection: " + Const.CR + variables.resolve(connection));
+    } catch (HopException e) {
+      throw new HopTransformException(
+          "Unable to get databaseMeta for connection: " + Const.CR + variables.resolve(connection));
     }
   }
 
@@ -691,7 +678,7 @@ public class VerticaBulkLoaderMeta
     String realSchemaName = variables.resolve(schemaName);
 
     DatabaseMeta databaseMeta =
-            getParentTransformMeta().getParentPipelineMeta().findDatabase(connection, variables);
+        getParentTransformMeta().getParentPipelineMeta().findDatabase(connection, variables);
 
     if (databaseMeta != null) {
       Database db = new Database(loggingObject, variables, databaseMeta);
@@ -729,21 +716,17 @@ public class VerticaBulkLoaderMeta
   /**
    * @return Fields containing the fieldnames in the database insert.
    */
-
   public String[] getFieldDatabase() {
     return fieldDatabase;
   }
 
-
-/**
+  /**
    * @param fieldDatabase The fields containing the names of the fields to insert.
    */
-
   public void setFieldDatabase(String[] fieldDatabase) {
     this.fieldDatabase = fieldDatabase;
   }
 
-
   /**
    * @return the schemaName
    */
@@ -778,7 +761,7 @@ public class VerticaBulkLoaderMeta
     List<String> items = Collections.emptyList();
     if (specifyFields()) {
       items = new ArrayList<>();
-      for(VerticaBulkLoaderField vbf : fields){
+      for (VerticaBulkLoaderField vbf : fields) {
         items.add(vbf.getFieldDatabase());
       }
     }
@@ -790,7 +773,7 @@ public class VerticaBulkLoaderMeta
     List<String> items = Collections.emptyList();
     if (specifyFields()) {
       items = new ArrayList<>();
-      for(VerticaBulkLoaderField vbf : fields){
+      for (VerticaBulkLoaderField vbf : fields) {
         items.add(vbf.getFieldStream());
       }
     }
