@@ -22,6 +22,7 @@ import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.exception.HopXmlException;
 import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.core.row.RowDataUtil;
+import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.core.xml.XmlParserFactoryProducer;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
@@ -260,7 +261,7 @@ public class XmlJoin extends BaseTransform<XmlJoinMeta, XmlJoinData> {
     }
 
     try {
-      Transformer transformer = TransformerFactory.newInstance().newTransformer();
+      Transformer transformer = XmlHandler.createSecureTransformerFactory().newTransformer();
 
       if (meta.getEncoding() != null) {
         transformer.setOutputProperty(OutputKeys.ENCODING, meta.getEncoding());
