@@ -29,7 +29,12 @@ import org.junit.Before;
 import org.junit.ClassRule;
 import org.junit.Test;
 
-import java.util.*;
+import java.util.Arrays;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.Random;
+import java.util.UUID;
 
 public class YamlInputMetaTest implements IInitializer<YamlInputMeta> {
   LoadSaveTester<YamlInputMeta> loadSaveTester;
