@@ -33,6 +33,7 @@ import org.apache.hop.ui.core.gui.GuiResource;
 import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.ColumnInfo;
 import org.apache.hop.ui.core.widget.TableView;
+import org.apache.hop.ui.hopgui.HopGui;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.KeyAdapter;
@@ -42,7 +43,11 @@ import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.layout.FormAttachment;
 import org.eclipse.swt.layout.FormData;
 import org.eclipse.swt.layout.FormLayout;
-import org.eclipse.swt.widgets.*;
+import org.eclipse.swt.widgets.Button;
+import org.eclipse.swt.widgets.Control;
+import org.eclipse.swt.widgets.Label;
+import org.eclipse.swt.widgets.Shell;
+import org.eclipse.swt.widgets.TableItem;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -148,12 +153,12 @@ public class PreviewRowsDialog {
     shell = new Shell(parentShell, style);
     PropsUi props = PropsUi.getInstance();
 
-    props.setLook(shell);
+    PropsUi.setLook(shell);
     shell.setImage(GuiResource.getInstance().getImageHopUi());
 
     FormLayout formLayout = new FormLayout();
-    formLayout.marginWidth = Const.FORM_MARGIN;
-    formLayout.marginHeight = Const.FORM_MARGIN;
+    formLayout.marginWidth = PropsUi.getFormMargin();
+    formLayout.marginHeight = PropsUi.getFormMargin();
 
     if (title == null) {
       title = BaseMessages.getString(PKG, "PreviewRowsDialog.Title");
@@ -251,7 +256,7 @@ public class PreviewRowsDialog {
     if (wlFields == null) {
       wlFields = new Label(shell, SWT.LEFT);
       wlFields.setText(message);
-      props.setLook(wlFields);
+      PropsUi.setLook(wlFields);
       FormData fdlFields = new FormData();
       fdlFields.left = new FormAttachment(0, 0);
       fdlFields.right = new FormAttachment(100, 0);
@@ -503,7 +508,7 @@ public class PreviewRowsDialog {
       return;
     }
 
-    Display.getDefault()
+    HopGui.getInstance().getDisplay()
         .syncExec(
             () -> {
               if (wFields.isDisposed()) {
