@@ -360,7 +360,7 @@ public class PipelineExecutionViewer extends BaseExecutionViewer
           }
         } catch (Exception e) {
           new ErrorDialog(
-              hopGui.getDisplay().getActiveShell(),
+              hopGui.getActiveShell(),
               "Error",
               "Hop was unable to invoke @GuiTab method "
                   + tabItem.getMethod().getName()
@@ -712,6 +712,7 @@ public class PipelineExecutionViewer extends BaseExecutionViewer
               propsUi.getZoomFactor(),
               Collections.emptyMap(),
               false,
+              null,
               Collections.emptyMap());
 
       // correct the magnification with the overall zoom factor
@@ -733,7 +734,7 @@ public class PipelineExecutionViewer extends BaseExecutionViewer
         viewPort = pipelinePainter.getViewPort();
         graphPort = pipelinePainter.getGraphPort();
       } catch (Exception e) {
-        new ErrorDialog(hopGui.getDisplay().getActiveShell(), "Error", "Error drawing pipeline image", e);
+        new ErrorDialog(hopGui.getActiveShell(), "Error", "Error drawing pipeline image", e);
       }
     } finally {
       gc.dispose();
