@@ -67,7 +67,12 @@ public class NoExtensionExplorerFileType
           "README file",
           "README file"
         },
-        FileTypeCapabilities.getCapabilities(IHopFileType.CAPABILITY_SAVE));
+        FileTypeCapabilities.getCapabilities(
+            IHopFileType.CAPABILITY_SAVE,
+            IHopFileType.CAPABILITY_CLOSE, 
+            IHopFileType.CAPABILITY_FILE_HISTORY,
+            IHopFileType.CAPABILITY_COPY, 
+            IHopFileType.CAPABILITY_SELECT));
   }
 
   @Override
